@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: calc_def.h 970 2005-04-24 09:41:50Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,8 +35,13 @@
 /* 
    A structure for creating a dirlist tree 
 */
+#ifndef __MACOSX__
+#include <glib.h>
+#else
+#include <glib/glib.h>
+#endif
 
-#include "tnode.h"
+typedef GNode TNode;
 
 
 /*
@@ -150,16 +152,9 @@ typedef struct {
 
   // Added here for maintain structure alignment
   int is_flash;
-
-  int (*recv_var_2) (char *filename, int mode, TiVarEntry * ve);
-
 } TicalcFunctions;
 typedef TicalcFunctions TicalcFncts;
 
-/* 
-	Callback 
-*/
-typedef int (*TICALC_PRINTL) (int level, const char *format, ...);
 
 /*********************/
 /* Macro definitions */
@@ -167,19 +162,13 @@ typedef int (*TICALC_PRINTL) (int level, const char *format, ...);
 
 
 typedef enum {
-  SCREEN_FULL, SCREEN_CLIPPED
+  FULL_SCREEN, CLIPPED_SCREEN
 } TicalcScreenFormat;
 
-#define FULL_SCREEN		SCREEN_FULL
-#define CLIPPED_SCREEN	SCREEN_CLIPPED
-
 typedef enum {
-  PATH_FULL, PATH_LOCAL
+  FULL_PATH, LOCAL_PATH
 } TicalcPathType;
 
-#define FULL_PATH	PATH_FULL
-#define LOCAL_PATH	PATH_LOCAL
-
 typedef enum {
   MEMORY_NONE, MEMORY_FREE, MEMORY_USED
 } TicalcMemoryType;
@@ -206,7 +195,7 @@ typedef enum {
 
 // ROM size for the ROM dump function
 typedef enum {
-  ROM_1MB = 1, ROM_2MB, ROM_SE,
+  ROM_1MB = 1, ROM_2MB
 } TicalcRomSize;
 
 // Shell to use with ROM dumping
