@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: cmd73.c 1397 2005-07-20 10:55:03Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +17,7 @@
  */
 
 /*
-  This unit handles TI73 & TI83+ & TI84+ commands.
+  This unit handles TI73 & TI83+ commands.
 */
 
 #include <stdio.h>
@@ -30,17 +27,12 @@
 #include "packets.h"
 #include "calc_err.h"
 #include "update.h"
-#include "printl.h"
 
-#ifdef __WIN32__
-#pragma warning( disable : 4761 )
-#endif
-
-// Shares some commands between TI73 & 83+ & 84+
+// Shares some commands between TI73 & 83+
 extern int ticalcs_calc_type;
 #define PC_TI7383 ((ticalcs_calc_type == CALC_TI73) ? PC_TI73 : PC_TI83p)
 #define TI7383_BKUP ((ticalcs_calc_type == CALC_TI73) ? TI73_BKUP : TI83p_BKUP)
-#define EXTRAS ((ticalcs_calc_type == CALC_TI83P) || (ticalcs_calc_type == CALC_TI84P) ? 2 : 0)
+#define EXTRAS ((ticalcs_calc_type == CALC_TI83P) ? 2 : 0)
 
 /* Variable (std var header: NUL padded, fixed length) */
 int ti73_send_VAR(uint16_t varsize, uint8_t vartype, char *varname,
@@ -97,7 +89,7 @@ int ti73_send_VAR2(uint32_t length, uint8_t type, uint8_t flag,
 
 int ti73_send_CTS(void)
 {
-  printl2(0, " PC->TI: CTS\n");
+  DISPLAY(" PC->TI: CTS\n");
   TRYF(send_packet(PC_TI7383, CMD_CTS, 0, NULL));
 
   return 0;
@@ -105,7 +97,7 @@ int ti73_send_CTS(void)
 
 int ti73_send_XDP(int length, uint8_t * data)
 {
-  printl2(0, " PC->TI: XDP (0x%04X = %i bytes)\n", length, length);
+  DISPLAY(" PC->TI: XDP (0x%04X = %i bytes)\n", length, length);
   TRYF(send_packet(PC_TI7383, CMD_XDP, length, data));
 
   return 0;
@@ -113,7 +105,7 @@ int ti73_send_XDP(int length, uint8_t * data)
 
 int ti73_send_FLSH(void)
 {
-  printl2(0, " PC->TI: FLASH app is following...\n");
+  DISPLAY(" PC->TI: FLASH app is following...\n");
   TRYF(send_packet(PC_TI7383, CMD_FLSH, 2, NULL));
 
   return 0;
@@ -126,16 +118,16 @@ int ti73_send_FLSH(void)
  */
 int ti73_send_SKIP(uint8_t rej_code)
 {
-  printl2(0, " PC->TI: SKIP\n");
+  DISPLAY(" PC->TI: SKIP\n");
   TRYF(send_packet(PC_TI7383, CMD_SKIP, 1, &rej_code));
-  printl2(0, " (rejection code = %i)\n", rej_code);
+  DISPLAY(" (rejection code = %i)\n", rej_code);
 
   return 0;
 }
 
 int ti73_send_ACK(void)
 {
-  printl2(0, " PC->TI: ACK\n");
+  DISPLAY(" PC->TI: ACK\n");
   TRYF(send_packet(PC_TI7383, CMD_ACK, 2, NULL));
 
   return 0;
@@ -143,7 +135,7 @@ int ti73_send_ACK(void)
 
 int ti73_send_ERR(void)
 {
-  printl2(0, " PC->TI: ERR\n");
+  DISPLAY(" PC->TI: ERR\n");
   TRYF(send_packet(PC_TI7383, CMD_ERR, 2, NULL));
 
   return 0;
@@ -151,7 +143,7 @@ int ti73_send_ERR(void)
 
 int ti73_send_RDY(void)
 {
-  printl2(0, " PC->TI: RDY?\n");
+  DISPLAY(" PC->TI: RDY?\n");
   TRYF(send_packet(PC_TI7383, CMD_RDY, 2, NULL));
 
   return 0;
@@ -159,7 +151,7 @@ int ti73_send_RDY(void)
 
 int ti73_send_SCR(void)
 {
-  printl2(0, " PC->TI: SCR\n");
+  DISPLAY(" PC->TI: SCR\n");
   TRYF(send_packet(PC_TI7383, CMD_SCR, 2, NULL));
 
   return 0;
@@ -169,7 +161,7 @@ int ti73_send_SCR(void)
 
 int ti73_send_KEY(uint16_t scancode)
 {
-  printl2(0, " PC->TI: KEY\n");
+  DISPLAY(" PC->TI: KEY\n");
   TRYF(cable->put(PC_TI7383));
   TRYF(cable->put(CMD_KEY));
   TRYF(cable->put(LSB(scancode)));
@@ -180,7 +172,7 @@ int ti73_send_KEY(uint16_t scancode)
 
 int ti73_send_EOT(void)
 {
-  printl2(0, " PC->TI: EOT\n");
+  DISPLAY(" PC->TI: EOT\n");
   TRYF(send_packet(PC_TI7383, CMD_EOT, 2, NULL));
 
   return 0;
@@ -193,7 +185,7 @@ int ti73_send_REQ(uint16_t varsize, uint8_t vartype, char *varname,
   uint8_t buffer[16] = { 0 };
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, (char*)trans, vartype);
+  tifiles_translate_varname(varname, trans, vartype);
   DISPLAY
       (" PC->TI: REQ (size=0x%04X=%i, id=%02X, name=<%s>, attr=%i)\n",
        varsize, varsize, vartype, trans, varattr);
@@ -221,7 +213,7 @@ int ti73_send_REQ2(uint16_t appsize, uint8_t apptype, char *appname,
 {
   uint8_t buffer[16] = { 0 };
 
-  printl2(0, " PC->TI: REQ (size=0x%04X=%i, id=%02X, name=<%s>)\n",
+  DISPLAY(" PC->TI: REQ (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  appsize, appsize, apptype, appname);
 
   buffer[0] = LSB(appsize);
@@ -242,7 +234,7 @@ int ti73_send_RTS(uint16_t varsize, uint8_t vartype, char *varname,
   uint8_t buffer[16];
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, (char*)trans, vartype);
+  tifiles_translate_varname(varname, trans, vartype);
   DISPLAY
       (" PC->TI: RTS (size=0x%04X=%i, id=%02X, name=<%s>, attr=%i)\n",
        varsize, varsize, vartype, trans, varattr);
@@ -268,11 +260,11 @@ int ti73_recv_VAR(uint16_t * varsize, uint8_t * vartype, char *varname,
 		  uint8_t * varattr)
 {
   uint8_t host, cmd;
-  uint8_t buffer[65536+6] = { 0 };
+  uint8_t buffer[16] = { 0 };
   uint16_t length;
   uint8_t trans[9];
 
-  printl2(0, " TI->PC: VAR");
+  DISPLAY(" TI->PC: VAR");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_EOT)
     return ERR_EOT;		// not really an error
@@ -289,10 +281,10 @@ int ti73_recv_VAR(uint16_t * varsize, uint8_t * vartype, char *varname,
   varname[8] = '\0';
   *varattr = (buffer[12] & 0x80) ? ATTRB_ARCHIVED : ATTRB_NONE;
 
-  tifiles_translate_varname(varname, (char*)trans, *vartype);
-  printl2(0, " (size=0x%04X=%i, id=%02X, name=<%s>, attrb=%i)",
+  tifiles_translate_varname(varname, trans, *vartype);
+  DISPLAY(" (size=0x%04X=%i, id=%02X, name=<%s>, attrb=%i)",
 	  *varsize, *varsize, *vartype, trans, *varattr);
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -302,10 +294,10 @@ int ti73_recv_VAR2(uint16_t * length, uint8_t * type, char *name,
 		   uint16_t * offset, uint16_t * page)
 {
   uint8_t host, cmd;
-  uint8_t buffer[65536+6] = { 0 };
+  uint8_t buffer[16] = { 0 };
   uint16_t len;
 
-  printl2(0, " TI->PC: VAR");
+  DISPLAY(" TI->PC: VAR");
   TRYF(recv_packet(&host, &cmd, &len, buffer));
   if (cmd == CMD_EOT)
     return ERR_EOT;		// not really an error
@@ -334,9 +326,9 @@ int ti73_recv_CTS(uint16_t length)
 {
   uint8_t host, cmd;
   uint16_t len;
-  uint8_t buffer[65536+6];
+  uint8_t buffer[5];
 
-  printl2(0, " TI->PC: CTS");
+  DISPLAY(" TI->PC: CTS");
   TRYF(recv_packet(&host, &cmd, &len, buffer));
   if (cmd == CMD_SKIP)
     return ERR_VAR_REJECTED;
@@ -344,7 +336,7 @@ int ti73_recv_CTS(uint16_t length)
     return ERR_INVALID_CMD;
   if (length != len)
     return ERR_CTS_ERROR;
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -353,19 +345,19 @@ int ti73_recv_SKIP(uint8_t * rej_code)
 {
   uint8_t host, cmd;
   uint16_t length;
-  uint8_t buffer[65536+6];
+  uint8_t buffer[5];
   *rej_code = 0;
 
-  printl2(0, " TI->PC: SKIP");
+  DISPLAY(" TI->PC: SKIP");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_CTS) {
-    printl2(0, "CTS");
+    DISPLAY("CTS");
     return 0;
   }
   if (cmd != CMD_SKIP)
     return ERR_INVALID_CMD;
-  printl2(0, " (rejection code = %i)", *rej_code = buffer[0]);
-  printl2(0, ".\n");
+  DISPLAY(" (rejection code = %i)", *rej_code = buffer[0]);
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -374,12 +366,12 @@ int ti73_recv_XDP(uint16_t * length, uint8_t * data)
 {
   uint8_t host, cmd;
 
-  printl2(0, " TI->PC: XDP");
+  DISPLAY(" TI->PC: XDP");
   TRYF(recv_packet(&host, &cmd, length, data));
   if (cmd != CMD_XDP)
     return ERR_INVALID_CMD;
-  printl2(0, " (%04X=%i bytes)", *length, *length);
-  printl2(0, ".\n");
+  DISPLAY(" (%04X=%i bytes)", *length, *length);
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -394,9 +386,9 @@ int ti73_recv_ACK(uint16_t * status)
 {
   uint8_t host, cmd;
   uint16_t length;
-  uint8_t buffer[65536+6];
+  uint8_t buffer[5];
 
-  printl2(0, " TI->PC: ACK");
+  DISPLAY(" TI->PC: ACK");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (status != NULL)
     *status = length;
@@ -405,7 +397,7 @@ int ti73_recv_ACK(uint16_t * status)
   if (cmd != CMD_ACK)
     return ERR_INVALID_CMD;
 
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -414,11 +406,11 @@ int ti73_recv_RTS(uint16_t * varsize, uint8_t * vartype, char *varname,
 		  uint8_t * varattr)
 {
   uint8_t host, cmd;
-  uint8_t buffer[65536+6];
+  uint8_t buffer[16];
   uint8_t trans[9];
 
 
-  printl2(0, " TI->PC: RTS");
+  DISPLAY(" TI->PC: RTS");
   TRYF(recv_packet(&host, &cmd, varsize, buffer));
   if (cmd != CMD_RTS)
     return ERR_INVALID_CMD;
@@ -428,10 +420,10 @@ int ti73_recv_RTS(uint16_t * varsize, uint8_t * vartype, char *varname,
   varname[8] = '\0';
   *varattr = (buffer[12] & 0x80) ? ATTRB_ARCHIVED : ATTRB_NONE;
 
-  tifiles_translate_varname(varname, (char*)trans, *vartype);
-  printl2(0, " (size=0x%04X=%i, id=%02X, name=<%s>, attrb=%i)",
+  tifiles_translate_varname(varname, trans, *vartype);
+  DISPLAY(" (size=0x%04X=%i, id=%02X, name=<%s>, attrb=%i)",
 	  *varsize, *varsize, *vartype, trans, *varattr);
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
