@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: cmd82.c 1397 2005-07-20 10:55:03Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,11 +28,6 @@
 #include "packets.h"
 #include "calc_err.h"
 #include "update.h"
-#include "printl.h"
-
-#ifdef __WIN32__
-#pragma warning( disable : 4761 )
-#endif
 
 // Shares some commands between TI82 & 83
 extern int ticalcs_calc_type;
@@ -48,8 +40,8 @@ int ti82_send_VAR(uint16_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[16];
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, (char*)trans, vartype);
-  printl2(0, " PC->TI: VAR (size=0x%04X=%i, id=%02X, name=<%s>)\n",
+  tifiles_translate_varname(varname, trans, vartype);
+  DISPLAY(" PC->TI: VAR (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
   buffer[0] = LSB(varsize);
@@ -69,7 +61,7 @@ int ti82_send_VAR(uint16_t varsize, uint8_t vartype, char *varname)
 
 int ti82_send_CTS(void)
 {
-  printl2(0, " PC->TI: CTS\n");
+  DISPLAY(" PC->TI: CTS\n");
   TRYF(send_packet(PC_TI8283, CMD_CTS, 0, NULL));
 
   return 0;
@@ -77,7 +69,7 @@ int ti82_send_CTS(void)
 
 int ti82_send_XDP(int length, uint8_t * data)
 {
-  printl2(0, " PC->TI: XDP (0x%04X = %i bytes)\n", length, length);
+  DISPLAY(" PC->TI: XDP (0x%04X = %i bytes)\n", length, length);
   TRYF(send_packet(PC_TI8283, CMD_XDP, length, data));
 
   return 0;
@@ -90,16 +82,16 @@ int ti82_send_XDP(int length, uint8_t * data)
  */
 int ti82_send_SKIP(uint8_t rej_code)
 {
-  printl2(0, " PC->TI: SKIP");
+  DISPLAY(" PC->TI: SKIP");
   TRYF(send_packet(PC_TI8283, CMD_SKIP, 1, &rej_code));
-  printl2(0, " (rejection code = %i)\n", rej_code);
+  DISPLAY(" (rejection code = %i)\n", rej_code);
 
   return 0;
 }
 
 int ti82_send_ACK(void)
 {
-  printl2(0, " PC->TI: ACK\n");
+  DISPLAY(" PC->TI: ACK\n");
   TRYF(send_packet(PC_TI8283, CMD_ACK, 2, NULL));
 
   return 0;
@@ -107,7 +99,7 @@ int ti82_send_ACK(void)
 
 int ti82_send_ERR(void)
 {
-  printl2(0, " PC->TI: ERR\n");
+  DISPLAY(" PC->TI: ERR\n");
   TRYF(send_packet(PC_TI8283, CMD_ERR, 2, NULL));
 
   return 0;
@@ -115,7 +107,7 @@ int ti82_send_ERR(void)
 
 int ti82_send_SCR(void)
 {
-  printl2(0, " PC->TI: SCR\n");
+  DISPLAY(" PC->TI: SCR\n");
   TRYF(send_packet(PC_TI8283, CMD_SCR, 2, NULL));
 
   return 0;
@@ -136,7 +128,7 @@ int ti82_send_SCR(void)
 
 int ti82_send_EOT(void)
 {
-  printl2(0, " PC->TI: EOT\n");
+  DISPLAY(" PC->TI: EOT\n");
   TRYF(send_packet(PC_TI8283, CMD_EOT, 2, NULL));
 
   return 0;
@@ -148,8 +140,8 @@ int ti82_send_REQ(uint16_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[16] = { 0 };
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, (char*)trans, vartype);
-  printl2(0, " PC->TI: REQ (size=0x%04X=%i, id=%02X, name=<%s>)\n",
+  tifiles_translate_varname(varname, trans, vartype);
+  DISPLAY(" PC->TI: REQ (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
   buffer[0] = LSB(varsize);
@@ -178,8 +170,8 @@ int ti82_send_RTS(uint16_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[16];
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, (char*)trans, vartype);
-  printl2(0, " PC->TI: RTS (size=0x%04X=%i, id=%02X, name=<%s>)\n",
+  tifiles_translate_varname(varname, trans, vartype);
+  DISPLAY(" PC->TI: RTS (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
   buffer[0] = LSB(varsize);
@@ -200,12 +192,12 @@ int ti82_send_RTS(uint16_t varsize, uint8_t vartype, char *varname)
 int ti82_recv_VAR(uint16_t * varsize, uint8_t * vartype, char *varname)
 {
   uint8_t host, cmd;
-  uint8_t buffer[65536+6] = { 0 };
+  uint8_t buffer[16] = { 0 };
   uint16_t length;
   uint8_t trans[9];
 
 
-  printl2(0, " TI->PC: VAR");
+  DISPLAY(" TI->PC: VAR");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_EOT)
     return ERR_EOT;		// not really an error
@@ -225,10 +217,10 @@ int ti82_recv_VAR(uint16_t * varsize, uint8_t * vartype, char *varname)
 
 
 
-  tifiles_translate_varname(varname, (char*)trans, *vartype);
-  printl2(0, " (size=0x%04X=%i, id=%02X, name=<%s>)",
+  tifiles_translate_varname(varname, trans, *vartype);
+  DISPLAY(" (size=0x%04X=%i, id=%02X, name=<%s>)",
 	  *varsize, *varsize, *vartype, trans);
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -238,7 +230,7 @@ int ti82_recv_CTS(void)
   uint8_t host, cmd;
   uint16_t length;
 
-  printl2(0, " TI->PC: CTS");
+  DISPLAY(" TI->PC: CTS");
   TRYF(recv_packet(&host, &cmd, &length, NULL));
   if (cmd == CMD_SKIP)
     return ERR_VAR_REJECTED;
@@ -246,7 +238,7 @@ int ti82_recv_CTS(void)
     return ERR_INVALID_CMD;
   if (length != 0x0000)
     return ERR_CTS_ERROR;
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -257,16 +249,16 @@ int ti82_recv_SKIP(uint8_t * rej_code)
   uint16_t length;
   *rej_code = 0;
 
-  printl2(0, " TI->PC: SKIP");
+  DISPLAY(" TI->PC: SKIP");
   TRYF(recv_packet(&host, &cmd, &length, rej_code));
   if (cmd == CMD_CTS) {
-    printl2(0, "->CTS.\n");
+    DISPLAY("->CTS.\n");
     return 0;
   }
   if (cmd != CMD_SKIP)
     return ERR_INVALID_CMD;
-  printl2(0, " (rejection code = %i)", *rej_code);
-  printl2(0, ".\n");
+  DISPLAY(" (rejection code = %i)", *rej_code);
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -275,12 +267,12 @@ int ti82_recv_XDP(uint16_t * length, uint8_t * data)
 {
   uint8_t host, cmd;
 
-  printl2(0, " TI->PC: XDP");
+  DISPLAY(" TI->PC: XDP");
   TRYF(recv_packet(&host, &cmd, length, data));
   if (cmd != CMD_XDP)
     return ERR_INVALID_CMD;
-  printl2(0, " (%04X=%i bytes)", *length, *length);
-  printl2(0, ".\n");
+  DISPLAY(" (%04X=%i bytes)", *length, *length);
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -297,7 +289,7 @@ int ti82_recv_ACK(uint16_t * status)
   uint16_t sts;
 
 
-  printl2(0, " TI->PC: ACK");
+  DISPLAY(" TI->PC: ACK");
   TRYF(recv_packet(&host, &cmd, &sts, NULL));
   if (status != NULL)
     *status = sts;
@@ -307,7 +299,7 @@ int ti82_recv_ACK(uint16_t * status)
     return ERR_INVALID_CMD;
 
 
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -315,11 +307,11 @@ int ti82_recv_ACK(uint16_t * status)
 int ti82_recv_RTS(uint16_t * varsize, uint8_t * vartype, char *varname)
 {
   uint8_t host, cmd;
-  uint8_t buffer[65536+6];
+  uint8_t buffer[16];
   uint8_t trans[9];
 
 
-  printl2(0, " TI->PC: RTS");
+  DISPLAY(" TI->PC: RTS");
   TRYF(recv_packet(&host, &cmd, varsize, buffer));
   if (cmd != CMD_RTS)
     return ERR_INVALID_CMD;
@@ -329,10 +321,10 @@ int ti82_recv_RTS(uint16_t * varsize, uint8_t * vartype, char *varname)
   varname[8] = '\0';
 
 
-  tifiles_translate_varname(varname, (char*)trans, *vartype);
-  printl2(0, " (size=0x%04X=%i, id=%02X, name=<%s>)",
+  tifiles_translate_varname(varname, trans, *vartype);
+  DISPLAY(" (size=0x%04X=%i, id=%02X, name=<%s>)",
 	  *varsize, *varsize, *vartype, trans);
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
