@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: cmd85.c 1397 2005-07-20 10:55:03Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,11 +28,6 @@
 #include "packets.h"
 #include "calc_err.h"
 #include "update.h"
-#include "printl.h"
-
-#ifdef __WIN32__
-#pragma warning( disable : 4761 )
-#endif
 
 // Shares some commands between TI85 & 86
 extern int ticalcs_calc_type;
@@ -48,8 +40,8 @@ int ti85_send_VAR(uint16_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[16];
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, (char*)trans, vartype);
-  printl2(0, " PC->TI: VAR (size=0x%04X=%i, id=%02X, name=<%s>)\n",
+  tifiles_translate_varname(varname, trans, vartype);
+  DISPLAY(" PC->TI: VAR (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
   buffer[0] = LSB(varsize);
@@ -71,7 +63,7 @@ int ti85_send_VAR(uint16_t varsize, uint8_t vartype, char *varname)
 
 int ti85_send_CTS(void)
 {
-  printl2(0, " PC->TI: CTS\n");
+  DISPLAY(" PC->TI: CTS\n");
   TRYF(send_packet(PC_TI8586, CMD_CTS, 0, NULL));
 
   return 0;
@@ -79,7 +71,7 @@ int ti85_send_CTS(void)
 
 int ti85_send_XDP(int length, uint8_t * data)
 {
-  printl2(0, " PC->TI: XDP (0x%04X = %i bytes)\n", length, length);
+  DISPLAY(" PC->TI: XDP (0x%04X = %i bytes)\n", length, length);
   TRYF(send_packet(PC_TI8586, CMD_XDP, length, data));
 
   return 0;
@@ -92,16 +84,16 @@ int ti85_send_XDP(int length, uint8_t * data)
  */
 int ti85_send_SKIP(uint8_t rej_code)
 {
-  printl2(0, " PC->TI: SKIP");
+  DISPLAY(" PC->TI: SKIP");
   TRYF(send_packet(PC_TI8586, CMD_SKIP, 1, &rej_code));
-  printl2(0, " (rejection code = %i)\n", rej_code);
+  DISPLAY(" (rejection code = %i)\n", rej_code);
 
   return 0;
 }
 
 int ti85_send_ACK(void)
 {
-  printl2(0, " PC->TI: ACK\n");
+  DISPLAY(" PC->TI: ACK\n");
   TRYF(send_packet(PC_TI8586, CMD_ACK, 2, NULL));
 
   return 0;
@@ -109,7 +101,7 @@ int ti85_send_ACK(void)
 
 int ti85_send_ERR(void)
 {
-  printl2(0, " PC->TI: ERR\n");
+  DISPLAY(" PC->TI: ERR\n");
   TRYF(send_packet(PC_TI8586, CMD_ERR, 2, NULL));
 
   return 0;
@@ -117,7 +109,7 @@ int ti85_send_ERR(void)
 
 int ti85_send_SCR(void)
 {
-  printl2(0, " PC->TI: SCR\n");
+  DISPLAY(" PC->TI: SCR\n");
   TRYF(send_packet(PC_TI8586, CMD_SCR, 2, NULL));
 
   return 0;
@@ -127,7 +119,7 @@ int ti85_send_SCR(void)
 
 int ti85_send_KEY(uint16_t scancode)
 {
-  printl2(0, " PC->TI: KEY\n");
+  DISPLAY(" PC->TI: KEY\n");
   TRYF(cable->put(PC_TI8586));
   TRYF(cable->put(CMD_KEY));
   TRYF(cable->put(LSB(scancode)));
@@ -138,7 +130,7 @@ int ti85_send_KEY(uint16_t scancode)
 
 int ti85_send_EOT(void)
 {
-  printl2(0, " PC->TI: EOT\n");
+  DISPLAY(" PC->TI: EOT\n");
   TRYF(send_packet(PC_TI8586, CMD_EOT, 2, NULL));
 
   return 0;
@@ -150,8 +142,8 @@ int ti85_send_REQ(uint16_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[16] = { 0 };
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, (char*)trans, vartype);
-  printl2(0, " PC->TI: REQ (size=0x%04X=%i, id=%02X, name=<%s>)\n",
+  tifiles_translate_varname(varname, trans, vartype);
+  DISPLAY(" PC->TI: REQ (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
   buffer[0] = LSB(varsize);
@@ -178,8 +170,8 @@ int ti85_send_RTS(uint16_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[16];
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, (char*)trans, vartype);
-  printl2(0, " PC->TI: RTS (size=0x%04X=%i, id=%02X, name=<%s>)\n",
+  tifiles_translate_varname(varname, trans, vartype);
+  DISPLAY(" PC->TI: RTS (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
   buffer[0] = LSB(varsize);
@@ -197,12 +189,12 @@ int ti85_send_RTS(uint16_t varsize, uint8_t vartype, char *varname)
 int ti85_recv_VAR(uint16_t * varsize, uint8_t * vartype, char *varname)
 {
   uint8_t host, cmd;
-  uint8_t buffer[65536+6] = { 0 };
+  uint8_t buffer[16] = { 0 };
   uint16_t length;
   uint8_t trans[9];
   uint8_t strl;
 
-  printl2(0, " TI->PC: VAR");
+  DISPLAY(" TI->PC: VAR");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_EOT)
     return ERR_EOT;		// not really an error
@@ -222,10 +214,10 @@ int ti85_recv_VAR(uint16_t * varsize, uint8_t * vartype, char *varname)
     memcpy(varname, buffer + 3, 8);
   }
 
-  tifiles_translate_varname(varname, (char*)trans, *vartype);
-  printl2(0, " (size=0x%04X=%i, id=%02X, name=<%s>)",
+  tifiles_translate_varname(varname, trans, *vartype);
+  DISPLAY(" (size=0x%04X=%i, id=%02X, name=<%s>)",
 	  *varsize, *varsize, *vartype, trans);
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -235,7 +227,7 @@ int ti85_recv_CTS(void)
   uint8_t host, cmd;
   uint16_t length;
 
-  printl2(0, " TI->PC: CTS");
+  DISPLAY(" TI->PC: CTS");
   TRYF(recv_packet(&host, &cmd, &length, NULL));
   if (cmd == CMD_SKIP)
     return ERR_VAR_REJECTED;
@@ -243,7 +235,7 @@ int ti85_recv_CTS(void)
     return ERR_INVALID_CMD;
   if (length != 0x0000)
     return ERR_CTS_ERROR;
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -254,16 +246,16 @@ int ti85_recv_SKIP(uint8_t * rej_code)
   uint16_t length;
   *rej_code = 0;
 
-  printl2(0, " TI->PC: SKIP");
+  DISPLAY(" TI->PC: SKIP");
   TRYF(recv_packet(&host, &cmd, &length, rej_code));
   if (cmd == CMD_CTS) {
-    printl2(0, "->CTS.\n");
+    DISPLAY("->CTS.\n");
     return 0;
   }
   if (cmd != CMD_SKIP)
     return ERR_INVALID_CMD;
-  printl2(0, " (rejection code = %i)", *rej_code);
-  printl2(0, ".\n");
+  DISPLAY(" (rejection code = %i)", *rej_code);
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -272,12 +264,12 @@ int ti85_recv_XDP(uint16_t * length, uint8_t * data)
 {
   uint8_t host, cmd;
 
-  printl2(0, " TI->PC: XDP");
+  DISPLAY(" TI->PC: XDP");
   TRYF(recv_packet(&host, &cmd, length, data));
   if (cmd != CMD_XDP)
     return ERR_INVALID_CMD;
-  printl2(0, " (%04X=%i bytes)", *length, *length);
-  printl2(0, ".\n");
+  DISPLAY(" (%04X=%i bytes)", *length, *length);
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -294,7 +286,7 @@ int ti85_recv_ACK(uint16_t * status)
   uint16_t sts;
 
 
-  printl2(0, " TI->PC: ACK");
+  DISPLAY(" TI->PC: ACK");
   TRYF(recv_packet(&host, &cmd, &sts, NULL));
   if (status != NULL)
     *status = sts;
@@ -304,7 +296,7 @@ int ti85_recv_ACK(uint16_t * status)
     return ERR_INVALID_CMD;
 
 
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -312,11 +304,11 @@ int ti85_recv_ACK(uint16_t * status)
 int ti85_recv_RTS(uint16_t * varsize, uint8_t * vartype, char *varname)
 {
   uint8_t host, cmd;
-  uint8_t buffer[65536+6];
+  uint8_t buffer[16];
   uint8_t trans[9];
   uint8_t strl;
 
-  printl2(0, " TI->PC: RTS");
+  DISPLAY(" TI->PC: RTS");
   TRYF(recv_packet(&host, &cmd, varsize, buffer));
   if (cmd != CMD_RTS)
     return ERR_INVALID_CMD;
@@ -326,10 +318,10 @@ int ti85_recv_RTS(uint16_t * varsize, uint8_t * vartype, char *varname)
   memcpy(varname, buffer + 4, strl);
   varname[strl] = '\0';
 
-  tifiles_translate_varname(varname, (char*)trans, *vartype);
-  printl2(0, " (size=0x%04X=%i, id=%02X, name=<%s>)",
+  tifiles_translate_varname(varname, trans, *vartype);
+  DISPLAY(" (size=0x%04X=%i, id=%02X, name=<%s>)",
 	  *varsize, *varsize, *vartype, trans);
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
