@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: cmd89.c 1397 2005-07-20 10:55:03Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,20 +27,14 @@
 #include "packets.h"
 #include "calc_err.h"
 #include "update.h"
-#include "printl.h"
 
-#ifdef __WIN32__
-#pragma warning( disable : 4761 4244)
-#endif
-
-// Shares some commands between TI89/92+/V200/TI89 Titanium
+// Shares some commands between TI89/92+/V200
 extern int ticalcs_calc_type;
 
 static uint8_t pc_ti9x(void)
 {
   switch (ticalcs_calc_type) {
   case CALC_TI89:
-  case CALC_TI89T:
     return PC_TI89;
     break;
   case CALC_TI92P:
@@ -65,11 +56,11 @@ static uint8_t pc_ti9x(void)
 int ti89_send_VAR(uint32_t varsize, uint8_t vartype, char *varname)
 {
   uint8_t buffer[32];
-  uint8_t trans[32];
+  uint8_t trans[9];
   uint8_t extra = (vartype == TI9X_BKUP) ? 0 : 1;
 
-  tifiles_translate_varname(varname, (char*)trans, vartype);
-  printl2(0, " PC->TI: VAR (size=0x%08X=%i, id=%02X, name=<%s>)\n",
+  tifiles_translate_varname(varname, trans, vartype);
+  DISPLAY(" PC->TI: VAR (size=0x%08X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
   buffer[0] = LSB(LSW(varsize));
@@ -88,7 +79,7 @@ int ti89_send_VAR(uint32_t varsize, uint8_t vartype, char *varname)
 
 int ti89_send_CTS(void)
 {
-  printl2(0, " PC->TI: CTS\n");
+  DISPLAY(" PC->TI: CTS\n");
   TRYF(send_packet(PC_TI9X, CMD_CTS, 2, NULL));
 
   return 0;
@@ -96,7 +87,7 @@ int ti89_send_CTS(void)
 
 int ti89_send_XDP(uint32_t length, uint8_t * data)
 {
-  printl2(0, " PC->TI: XDP (0x%04X = %i)\n", length, length);
+  DISPLAY(" PC->TI: XDP (0x%04X = %i)\n", length, length);
   TRYF(send_packet(PC_TI9X, CMD_XDP, length, data));
 
   return 0;
@@ -113,16 +104,16 @@ int ti89_send_SKIP(uint8_t rej_code)
 
   buffer[0] = rej_code;
 
-  printl2(0, " PC->TI: SKIP");
+  DISPLAY(" PC->TI: SKIP");
   TRYF(send_packet(PC_TI9X, CMD_SKIP, 3, buffer));
-  printl2(0, " (rejection code = %i)\n", rej_code);
+  DISPLAY(" (rejection code = %i)\n", rej_code);
 
   return 0;
 }
 
 int ti89_send_ACK(void)
 {
-  printl2(0, " PC->TI: ACK\n");
+  DISPLAY(" PC->TI: ACK\n");
   TRYF(send_packet(PC_TI9X, CMD_ACK, 2, NULL));
 
   return 0;
@@ -130,7 +121,7 @@ int ti89_send_ACK(void)
 
 int ti89_send_ERR(void)
 {
-  printl2(0, " PC->TI: ERR\n");
+  DISPLAY(" PC->TI: ERR\n");
   TRYF(send_packet(PC_TI9X, CMD_ERR, 2, NULL));
 
   return 0;
@@ -138,7 +129,7 @@ int ti89_send_ERR(void)
 
 int ti89_send_RDY(void)
 {
-  printl2(0, " PC->TI: RDY?\n");
+  DISPLAY(" PC->TI: RDY?\n");
   TRYF(send_packet(PC_TI9X, CMD_RDY, 2, NULL));
 
   return 0;
@@ -146,7 +137,7 @@ int ti89_send_RDY(void)
 
 int ti89_send_SCR(void)
 {
-  printl2(0, " PC->TI: SCR\n");
+  DISPLAY(" PC->TI: SCR\n");
   TRYF(send_packet(PC_TI9X, CMD_SCR, 2, NULL));
 
   return 0;
@@ -154,7 +145,7 @@ int ti89_send_SCR(void)
 
 int ti89_send_CONT(void)
 {
-  printl2(0, " PC->TI: CONT\n");
+  DISPLAY(" PC->TI: CONT\n");
   TRYF(send_packet(PC_TI9X, CMD_CONT, 2, NULL));
 
   return 0;
@@ -164,7 +155,7 @@ int ti89_send_CONT(void)
 
 int ti89_send_KEY(uint16_t scancode)
 {
-  printl2(0, " PC->TI: KEY\n");
+  DISPLAY(" PC->TI: KEY\n");
   TRYF(cable->put(PC_TI9X));
   TRYF(cable->put(CMD_KEY));
   TRYF(cable->put(LSB(scancode)));
@@ -175,7 +166,7 @@ int ti89_send_KEY(uint16_t scancode)
 
 int ti89_send_EOT(void)
 {
-  printl2(0, " PC->TI: EOT\n");
+  DISPLAY(" PC->TI: EOT\n");
   TRYF(send_packet(PC_TI9X, CMD_EOT, 2, NULL));
 
   return 0;
@@ -186,7 +177,7 @@ int ti89_send_REQ(uint32_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[32] = { 0 };
   uint16_t len;
 
-  printl2(0, " PC->TI: REQ (size=0x%08X=%i, id=%02X, name=<%s>)\n",
+  DISPLAY(" PC->TI: REQ (size=0x%08X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, varname);
 
   buffer[0] = LSB(LSW(varsize));
@@ -211,7 +202,7 @@ int ti89_send_RTS(uint32_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[32] = { 0 };
   uint16_t len;
 
-  printl2(0, " PC->TI: RTS (size=0x%08X=%i, id=%02X, name=<%s>)\n",
+  DISPLAY(" PC->TI: RTS (size=0x%08X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, varname);
 
   buffer[0] = LSB(LSW(varsize));
@@ -224,32 +215,8 @@ int ti89_send_RTS(uint32_t varsize, uint8_t vartype, char *varname)
   buffer[6 + strlen(varname)] = 0x00;
 
   len = 6 + strlen(varname) + 1;
-  // used by AMS <= 2.09 ?
-  //if ((vartype == TI89_AMS) || (vartype == TI89_APPL)) len--;
-  TRYF(send_packet(PC_TI9X, CMD_RTS, len, buffer));
-
-  return 0;
-}
-
-int ti89_send_RTS2(uint32_t varsize, uint8_t vartype, char *varname)
-{
-  uint8_t buffer[32] = { 0 };
-  uint16_t len;
-
-  printl2(0, " PC->TI: RTS (size=0x%08X=%i, id=%02X, name=<%s>)\n",
-	  varsize, varsize, vartype, varname);
-
-  buffer[0] = LSB(LSW(varsize));
-  buffer[1] = MSB(LSW(varsize));
-  buffer[2] = LSB(MSW(varsize));
-  buffer[3] = MSB(MSW(varsize));
-  buffer[4] = vartype;
-  buffer[5] = 0x00;
-  buffer[6] = 0x08;
-  buffer[7] = 0x00;
-  buffer[8] = 0x09;
-
-  len = 9;
+  if ((vartype == TI89_AMS) || (vartype == TI89_APPL))
+    len--;
   TRYF(send_packet(PC_TI9X, CMD_RTS, len, buffer));
 
   return 0;
@@ -260,12 +227,12 @@ int ti89_send_RTS2(uint32_t varsize, uint8_t vartype, char *varname)
 int ti89_recv_VAR(uint32_t * varsize, uint8_t * vartype, char *varname)
 {
   uint8_t host, cmd;
-  uint8_t buffer[65536+6] = { 0 };
+  uint8_t buffer[32] = { 0 };
   uint16_t length;
   uint8_t strl;
   uint8_t flag;
 
-  printl2(0, " TI->PC: VAR");
+  DISPLAY(" TI->PC: VAR");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_EOT)
     return ERR_EOT;		// not really an error
@@ -286,9 +253,9 @@ int ti89_recv_VAR(uint32_t * varsize, uint8_t * vartype, char *varname)
       (length != (7 + strlen(varname))))
     return ERR_INVALID_PACKET;
 
-  printl2(0, " (size=0x%08X=%i, id=%02X, name=<%s>, flag=%i)",
+  DISPLAY(" (size=0x%08X=%i, id=%02X, name=<%s>, flag=%i)",
 	  *varsize, *varsize, *vartype, varname, flag);
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -297,9 +264,9 @@ int ti89_recv_CTS(void)
 {
   uint8_t host, cmd;
   uint16_t length;
-  uint8_t buffer[65536+6];
+  uint8_t buffer[5];
 
-  printl2(0, " TI->PC: CTS");
+  DISPLAY(" TI->PC: CTS");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_SKIP)
     return ERR_VAR_REJECTED;
@@ -307,7 +274,7 @@ int ti89_recv_CTS(void)
     return ERR_INVALID_CMD;
   if (length != 0x0000)
     return ERR_CTS_ERROR;
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -316,19 +283,19 @@ int ti89_recv_SKIP(uint8_t * rej_code)
 {
   uint8_t host, cmd;
   uint16_t length;
-  uint8_t buffer[65536+6];
+  uint8_t buffer[5];
   *rej_code = 0;
 
-  printl2(0, " TI->PC: SKIP");
+  DISPLAY(" TI->PC: SKIP");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_CTS) {
-    printl2(0, "CTS");
+    DISPLAY("CTS");
     return 0;
   }
   if (cmd != CMD_SKIP)
     return ERR_INVALID_CMD;
-  printl2(0, " (rejection code = %i)", *rej_code = buffer[0]);
-  printl2(0, ".\n");
+  DISPLAY(" (rejection code = %i)", *rej_code = buffer[0]);
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -338,13 +305,13 @@ int ti89_recv_XDP(uint32_t * length, uint8_t * data)
   uint8_t host, cmd;
   int err;
 
-  printl2(0, " TI->PC: XDP");
+  DISPLAY(" TI->PC: XDP");
   err = recv_packet(&host, &cmd, (uint16_t *) length, data);
   fixup(*length);
   if (cmd != CMD_XDP)
     return ERR_INVALID_CMD;
-  printl2(0, " (%04X=%i bytes)", *length, *length);
-  printl2(0, ".\n");
+  DISPLAY(" (%04X=%i bytes)", *length, *length);
+  DISPLAY(".\n");
   TRYF(err);
 
   return 0;
@@ -360,9 +327,9 @@ int ti89_recv_ACK(uint16_t * status)
 {
   uint8_t host, cmd;
   uint16_t length;
-  uint8_t buffer[65536+6];
+  uint8_t buffer[5];
 
-  printl2(0, " TI->PC: ACK");
+  DISPLAY(" TI->PC: ACK");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_SKIP)
     return ERR_VAR_REJECTED;
@@ -373,7 +340,7 @@ int ti89_recv_ACK(uint16_t * status)
   if (cmd != CMD_ACK)
     return ERR_INVALID_CMD;
 
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -384,13 +351,13 @@ int ti89_recv_CONT(void)
   uint16_t sts;
 
 
-  printl2(0, " TI->PC: CONT");
+  DISPLAY(" TI->PC: CONT");
   TRYF(recv_packet(&host, &cmd, &sts, NULL));
   if (cmd == CMD_EOT)
     return ERR_EOT;		// not really an error
   if (cmd != CMD_CONT)
     return ERR_INVALID_CMD;
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -400,11 +367,11 @@ int ti89_recv_EOT(void)
   uint8_t host, cmd;
   uint16_t length;
 
-  printl2(0, " TI->PC: EOT");
+  DISPLAY(" TI->PC: EOT");
   TRYF(recv_packet(&host, &cmd, &length, NULL));
   if (cmd != CMD_EOT)
     return ERR_INVALID_CMD;
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -412,11 +379,11 @@ int ti89_recv_EOT(void)
 int ti89_recv_RTS(uint32_t * varsize, uint8_t * vartype, char *varname)
 {
   uint8_t host, cmd;
-  uint8_t buffer[65536+6] = { 0 };
+  uint8_t buffer[32] = { 0 };
   uint16_t length;
   uint8_t strl;
 
-  printl2(0, " TI->PC: RTS");
+  DISPLAY(" TI->PC: RTS");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_EOT)
     return ERR_EOT;		// not really an error
@@ -435,9 +402,9 @@ int ti89_recv_RTS(uint32_t * varsize, uint8_t * vartype, char *varname)
   if (length != (6 + strlen(varname)))
     return ERR_INVALID_PACKET;
 
-  printl2(0, " (size=0x%08X=%i, id=%02X, name=<%s>)",
+  DISPLAY(" (size=0x%08X=%i, id=%02X, name=<%s>)",
 	  *varsize, *varsize, *vartype, varname);
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
