@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: cmd92.c 1397 2005-07-20 10:55:03Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,19 +27,15 @@
 #include "packets.h"
 #include "calc_err.h"
 #include "update.h"
-#include "printl.h"
 
-#ifdef __WIN32__
-#pragma warning( disable : 4761 4244)
-#endif
 
 int ti92_send_VAR(uint32_t varsize, uint8_t vartype, char *varname)
 {
   uint8_t buffer[32];
-  uint8_t trans[32];
+  uint8_t trans[9];
 
-  tifiles_translate_varname(varname, (char*)trans, vartype);
-  printl2(0, " PC->TI: VAR (size=0x%08X=%i, id=%02X, name=<%s>)\n",
+  tifiles_translate_varname(varname, trans, vartype);
+  DISPLAY(" PC->TI: VAR (size=0x%08X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
   buffer[0] = LSB(LSW(varsize));
@@ -60,7 +53,7 @@ int ti92_send_VAR(uint32_t varsize, uint8_t vartype, char *varname)
 
 int ti92_send_CTS(void)
 {
-  printl2(0, " PC->TI: CTS\n");
+  DISPLAY(" PC->TI: CTS\n");
   TRYF(send_packet(PC_TI92, CMD_CTS, 2, NULL));
 
   return 0;
@@ -68,7 +61,7 @@ int ti92_send_CTS(void)
 
 int ti92_send_XDP(uint32_t length, uint8_t * data)
 {
-  printl2(0, " PC->TI: XDP (0x%04X = %i bytes)\n", length, length);
+  DISPLAY(" PC->TI: XDP (0x%04X = %i bytes)\n", length, length);
   TRYF(send_packet(PC_TI92, CMD_XDP, length, data));
 
   return 0;
@@ -81,16 +74,16 @@ int ti92_send_XDP(uint32_t length, uint8_t * data)
  */
 int ti92_send_SKIP(uint8_t rej_code)
 {
-  printl2(0, " PC->TI: SKIP");
+  DISPLAY(" PC->TI: SKIP");
   TRYF(send_packet(PC_TI92, CMD_SKIP, 1, &rej_code));
-  printl2(0, " (rejection code = %i)\n", rej_code);
+  DISPLAY(" (rejection code = %i)\n", rej_code);
 
   return 0;
 }
 
 int ti92_send_ACK(void)
 {
-  printl2(0, " PC->TI: ACK\n");
+  DISPLAY(" PC->TI: ACK\n");
   TRYF(send_packet(PC_TI92, CMD_ACK, 2, NULL));
 
   return 0;
@@ -98,7 +91,7 @@ int ti92_send_ACK(void)
 
 int ti92_send_ERR(void)
 {
-  printl2(0, " PC->TI: ERR\n");
+  DISPLAY(" PC->TI: ERR\n");
   TRYF(send_packet(PC_TI92, CMD_ERR, 2, NULL));
 
   return 0;
@@ -106,7 +99,7 @@ int ti92_send_ERR(void)
 
 int ti92_send_RDY(void)
 {
-  printl2(0, " PC->TI: RDY?\n");
+  DISPLAY(" PC->TI: RDY?\n");
   TRYF(send_packet(PC_TI92, CMD_RDY, 2, NULL));
 
   return 0;
@@ -114,7 +107,7 @@ int ti92_send_RDY(void)
 
 int ti92_send_SCR(void)
 {
-  printl2(0, " PC->TI: SCR\n");
+  DISPLAY(" PC->TI: SCR\n");
   TRYF(send_packet(PC_TI92, CMD_SCR, 2, NULL));
 
   return 0;
@@ -122,7 +115,7 @@ int ti92_send_SCR(void)
 
 int ti92_send_CONT(void)
 {
-  printl2(0, " PC->TI: CONT\n");
+  DISPLAY(" PC->TI: CONT\n");
   TRYF(send_packet(PC_TI92, CMD_CONT, 2, NULL));
 
   return 0;
@@ -132,7 +125,7 @@ int ti92_send_CONT(void)
 
 int ti92_send_KEY(uint16_t scancode)
 {
-  printl2(0, " PC->TI: KEY\n");
+  DISPLAY(" PC->TI: KEY\n");
   TRYF(cable->put(PC_TI92));
   TRYF(cable->put(CMD_KEY));
   TRYF(cable->put(LSB(scancode)));
@@ -143,7 +136,7 @@ int ti92_send_KEY(uint16_t scancode)
 
 int ti92_send_EOT(void)
 {
-  printl2(0, " PC->TI: EOT\n");
+  DISPLAY(" PC->TI: EOT\n");
   TRYF(send_packet(PC_TI92, CMD_EOT, 2, NULL));
 
   return 0;
@@ -153,7 +146,7 @@ int ti92_send_REQ(uint32_t varsize, uint8_t vartype, char *varname)
 {
   uint8_t buffer[32] = { 0 };
 
-  printl2(0, " PC->TI: REQ (size=0x%08X=%i, id=%02X, name=<%s>)\n",
+  DISPLAY(" PC->TI: REQ (size=0x%08X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, varname);
 
   buffer[0] = 0;
@@ -173,7 +166,7 @@ int ti92_send_RTS(uint32_t varsize, uint8_t vartype, char *varname)
 {
   uint8_t buffer[32] = { 0 };
 
-  printl2(0, " PC->TI: REQ (size=0x%08X=%i, id=%02X, name=<%s>)\n",
+  DISPLAY(" PC->TI: REQ (size=0x%08X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, varname);
 
   buffer[0] = 0;
@@ -198,7 +191,7 @@ int ti92_recv_VAR(uint32_t * varsize, uint8_t * vartype, char *varname)
   uint16_t length;
   uint8_t strl;
 
-  printl2(0, " TI->PC: VAR");
+  DISPLAY(" TI->PC: VAR");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_EOT)
     return ERR_EOT;		// not really an error
@@ -217,9 +210,9 @@ int ti92_recv_VAR(uint32_t * varsize, uint8_t * vartype, char *varname)
   if (length != (6 + strlen(varname)))
     return ERR_INVALID_PACKET;
 
-  printl2(0, " (size=0x%08X=%i, id=%02X, name=<%s>)",
+  DISPLAY(" (size=0x%08X=%i, id=%02X, name=<%s>)",
 	  *varsize, *varsize, *vartype, varname);
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -230,7 +223,7 @@ int ti92_recv_CTS(void)
   uint16_t length;
   uint8_t buffer[5];
 
-  printl2(0, " TI->PC: CTS");
+  DISPLAY(" TI->PC: CTS");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_SKIP)
     return ERR_VAR_REJECTED;
@@ -238,7 +231,7 @@ int ti92_recv_CTS(void)
     return ERR_INVALID_CMD;
   if (length != 0x0000)
     return ERR_CTS_ERROR;
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -250,16 +243,16 @@ int ti92_recv_SKIP(uint8_t * rej_code)
   uint8_t buffer[5];
   *rej_code = 0;
 
-  printl2(0, " TI->PC: SKIP");
+  DISPLAY(" TI->PC: SKIP");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_CTS) {
-    printl2(0, "CTS");
+    DISPLAY("CTS");
     return 0;
   }
   if (cmd != CMD_SKIP)
     return ERR_INVALID_CMD;
-  printl2(0, " (rejection code = %i)", *rej_code = buffer[0]);
-  printl2(0, ".\n");
+  DISPLAY(" (rejection code = %i)", *rej_code = buffer[0]);
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -269,13 +262,13 @@ int ti92_recv_XDP(uint32_t * length, uint8_t * data)
   uint8_t host, cmd;
   int err;
 
-  printl2(0, " TI->PC: XDP");
+  DISPLAY(" TI->PC: XDP");
   err = recv_packet(&host, &cmd, (uint16_t *) length, data);
   fixup(*length);
   if (cmd != CMD_XDP)
     return ERR_INVALID_CMD;
-  printl2(0, " (%04X=%i bytes)", *length, *length);
-  printl2(0, ".\n");
+  DISPLAY(" (%04X=%i bytes)", *length, *length);
+  DISPLAY(".\n");
   TRYF(err);
 
   return 0;
@@ -293,7 +286,7 @@ int ti92_recv_ACK(uint16_t * status)
   uint16_t length;
   uint8_t buffer[5];
 
-  printl2(0, " TI->PC: ACK");
+  DISPLAY(" TI->PC: ACK");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (status != NULL)
     *status = length;
@@ -302,7 +295,7 @@ int ti92_recv_ACK(uint16_t * status)
   if (cmd != CMD_ACK)
     return ERR_INVALID_CMD;
 
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -313,13 +306,13 @@ int ti92_recv_CONT(void)
   uint16_t sts;
 
 
-  printl2(0, " TI->PC: CONT");
+  DISPLAY(" TI->PC: CONT");
   TRYF(recv_packet(&host, &cmd, &sts, NULL));
   if (cmd == CMD_EOT)
     return ERR_EOT;		// not really an error
   if (cmd != CMD_CONT)
     return ERR_INVALID_CMD;
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -329,11 +322,11 @@ int ti92_recv_EOT(void)
   uint8_t host, cmd;
   uint16_t length;
 
-  printl2(0, " TI->PC: EOT");
+  DISPLAY(" TI->PC: EOT");
   TRYF(recv_packet(&host, &cmd, &length, NULL));
   if (cmd != CMD_EOT)
     return ERR_INVALID_CMD;
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
@@ -345,7 +338,7 @@ int ti92_recv_RTS(uint32_t * varsize, uint8_t * vartype, char *varname)
   uint16_t length;
   uint8_t strl;
 
-  printl2(0, " TI->PC: VAR");
+  DISPLAY(" TI->PC: VAR");
   TRYF(recv_packet(&host, &cmd, &length, buffer));
   if (cmd == CMD_EOT)
     return ERR_EOT;		// not really an error
@@ -364,9 +357,9 @@ int ti92_recv_RTS(uint32_t * varsize, uint8_t * vartype, char *varname)
   if (length != (6 + strlen(varname)))
     return ERR_INVALID_PACKET;
 
-  printl2(0, " (size=0x%08X=%i, id=%02X, name=<%s>)",
+  DISPLAY(" (size=0x%08X=%i, id=%02X, name=<%s>)",
 	  *varsize, *varsize, *vartype, varname);
-  printl2(0, ".\n");
+  DISPLAY(".\n");
 
   return 0;
 }
