@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: dirlist.c 733 2004-05-28 21:11:48Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,14 +25,12 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "gettext.h"
-
 #include "calc_def.h"
 #include "headers.h"
-#include "tnode.h"
-#include "printl.h"
+#include "intl2.h"
 
-static tboolean free_varentry(TNode * node, tpointer data)
+
+static gboolean free_varentry(GNode * node, gpointer data)
 {
   if (node)
     free(node->data);
@@ -45,9 +40,9 @@ static tboolean free_varentry(TNode * node, tpointer data)
 TIEXPORT void TICALL ticalc_dirlist_destroy(TNode ** tree)
 {
   if (*tree != NULL) {
-    t_node_traverse(*tree, T_IN_ORDER, T_TRAVERSE_ALL, -1,
+    g_node_traverse(*tree, G_IN_ORDER, G_TRAVERSE_ALL, -1,
 		    free_varentry, NULL);
-    t_node_destroy(*tree);
+    g_node_destroy(*tree);
     *tree = NULL;
   }
 }
@@ -58,58 +53,58 @@ static void dirlist_display_vars(TNode * tree)
   int i, j, k;
   TNode *vars = tree;
 
-  printl2(0,   "+------------------+----------+----+----+----------+----------+\n");
-  printl2(0, _("| B. name          | T. name  |Attr|Type| Size     | Parent   |\n"));
-  printl2(0,   "+------------------+----------+----+----+----------+----------+\n");
+  DISPLAY("+------------------+----------+----+----+----------+----------+\n");
+  DISPLAY(_("| B. name          | T. name  |Attr|Type| Size     | Parent   |\n"));
+  DISPLAY("+------------------+----------+----+----+----------+----------+\n");
 
-  for (i = 0; i < (int)t_node_n_children(vars); i++)	// parse folders
+  for (i = 0; i < g_node_n_children(vars); i++)	// parse folders
   {
-    TNode *parent = t_node_nth_child(vars, i);
+    GNode *parent = g_node_nth_child(vars, i);
     TiVarEntry *fe = (TiVarEntry *) (parent->data);
 
     if (fe != NULL) {
-      printl2(0, "| ");
+      DISPLAY("| ");
       for (k = 0; k < 8; k++)
-	printl2(0, "%02X", (uint8_t) (fe->name)[k]);
-      printl2(0, " | ");	
-      printl2(0, "%8s", fe->trans);
-      printl2(0, " | ");
-      printl2(0, "%2i", fe->attr);
-      printl2(0, " | ");
-      printl2(0, "%02X", fe->type);
-      printl2(0, " | ");
-      printl2(0, "%08X", fe->size);
-      printl2(0, " | ");
-      printl2(0, "%8s", fe->folder);
-      printl2(0, " |\n");
+	DISPLAY("%02X", (uint8_t) (fe->name)[k]);
+      DISPLAY(" | ");	
+      DISPLAY("%8s", fe->trans);
+      DISPLAY(" | ");
+      DISPLAY("%2i", fe->attr);
+      DISPLAY(" | ");
+      DISPLAY("%02X", fe->type);
+      DISPLAY(" | ");
+      DISPLAY("%08X", fe->size);
+      DISPLAY(" | ");
+      DISPLAY("%8s", fe->folder);
+      DISPLAY(" |\n");
     }
 
-    for (j = 0; j < (int)t_node_n_children(parent); j++)	//parse variables
+    for (j = 0; j < g_node_n_children(parent); j++)	//parse variables
     {
-      TNode *child = t_node_nth_child(parent, j);
+      GNode *child = g_node_nth_child(parent, j);
       TiVarEntry *ve = (TiVarEntry *) (child->data);
 
-      printl2(0, "| ");
+      DISPLAY("| ");
       for (k = 0; k < 8; k++) {
-	printl2(0, "%02X", (uint8_t) (ve->name)[k]);
+	DISPLAY("%02X", (uint8_t) (ve->name)[k]);
       }
-      printl2(0, " | ");
-      printl2(0, "%8s", ve->trans);
-      printl2(0, " | ");
-      printl2(0, "%2i", ve->attr);
-      printl2(0, " | ");
-      printl2(0, "%02X", ve->type);
-      printl2(0, " | ");
-      printl2(0, "%08X", ve->size);
-      printl2(0, " | ");
-      printl2(0, "%8s", ve->folder);
-      printl2(0, " |\n");
+      DISPLAY(" | ");
+      DISPLAY("%8s", ve->trans);
+      DISPLAY(" | ");
+      DISPLAY("%2i", ve->attr);
+      DISPLAY(" | ");
+      DISPLAY("%02X", ve->type);
+      DISPLAY(" | ");
+      DISPLAY("%08X", ve->size);
+      DISPLAY(" | ");
+      DISPLAY("%8s", ve->folder);
+      DISPLAY(" |\n");
     }
   }
   if (!i)
-    printl2(0, _("  No variables\n"));
+    DISPLAY(_("  No variables\n"));
 
-  printl2(0, _
+  DISPLAY(_
 	  ("+------------------+----------+----+----+----------+----------+\n"));
 }
 
@@ -118,34 +113,34 @@ static void dirlist_display_apps(TNode * tree)
   int i, k;
   TNode *apps = tree;
 
-  printl2(0,   "+------------------+----------+----+----+----------+\n");
-  printl2(0, _("| B. name          | T. name  |Attr|Type| Size     |\n"));
-  printl2(0,   "+------------------+----------+----+----+----------+\n");
+  DISPLAY("+------------------+----------+----+----+----------+\n");
+  DISPLAY(_("| B. name          | T. name  |Attr|Type| Size     |\n"));
+  DISPLAY("+------------------+----------+----+----+----------+\n");
 
-  for (i = 0; i < (int)t_node_n_children(apps); i++) {
-    TNode *child = t_node_nth_child(apps, i);
+  for (i = 0; i < g_node_n_children(apps); i++) {
+    GNode *child = g_node_nth_child(apps, i);
 
     TiVarEntry *ve = (TiVarEntry *) (child->data);
 
-    printl2(0, "| ");
+    DISPLAY("| ");
     for (k = 0; k < 8; k++) {
-      printl2(0, "%02X", (uint8_t) (ve->name)[k]);
+      DISPLAY("%02X", (uint8_t) (ve->name)[k]);
     }
-    printl2(0, " | ");
-    printl2(0, "%8s", ve->trans);
-    printl2(0, " | ");
-    printl2(0, "%2i", ve->attr);
-    printl2(0, " | ");
-    printl2(0, "%02X", ve->type);
-    printl2(0, " | ");
-    printl2(0, "%08X", ve->size);
-    printl2(0, " |\n");
+    DISPLAY(" | ");
+    DISPLAY("%8s", ve->trans);
+    DISPLAY(" | ");
+    DISPLAY("%2i", ve->attr);
+    DISPLAY(" | ");
+    DISPLAY("%02X", ve->type);
+    DISPLAY(" | ");
+    DISPLAY("%08X", ve->size);
+    DISPLAY(" |\n");
   }
   if (!i)
-    printl2(0, _("  No applications\n"));
+    DISPLAY(_("  No applications\n"));
 
-  printl2(0, "+------------------+----------+----+----+----------+\n");
-  printl2(0, "\n");
+  DISPLAY("+------------------+----------+----+----+----------+\n");
+  DISPLAY("\n");
 }
 
 
@@ -157,14 +152,14 @@ static void dirlist_display1(TNode * tree)
     return;
 
   // List variables
-  vars = t_node_nth_child(tree, 0);
+  vars = g_node_nth_child(tree, 0);
   if (vars == NULL)
     return;
 
   dirlist_display_vars(vars);
 
   // List applications
-  apps = t_node_nth_child(tree, 1);
+  apps = g_node_nth_child(tree, 1);
   if (apps == NULL)
     return;
 
@@ -179,20 +174,20 @@ TIEXPORT void TICALL ticalc_dirlist_display(TNode * tree)
 
   // Determine tree format
   if (tree->data == NULL) {
-    printl2(0, "dirlist form #1: vars & apps\n");
+    DISPLAY("dirlist form #1: vars & apps\n");
     dirlist_display1(tree);
   } else {
     char *node_name = (char *) tree->data;
 
     if (!strcmp(node_name, VAR_NODE_NAME)) {
-	    printl2(0, "dirlist form #2: vars\n");
+	    DISPLAY("dirlist form #2: vars\n");
 	    dirlist_display_vars(tree);
     } else if (!strcmp(node_name, APP_NODE_NAME)) {
-	    printl2(0, "dirlist form #2: apps\n");
+	    DISPLAY("dirlist form #2: apps\n");
 	    dirlist_display_apps(tree);
     } else {
-      printl2(2, "invalid tree !\n");
-      printl2(2, "Program halted before crashing...\n");
+      DISPLAY_ERROR("libticalcs: invalid tree !\n");
+      DISPLAY_ERROR("Program halted before crashing...\n");
       exit(-1);
     }
   }
@@ -214,7 +209,7 @@ TIEXPORT TiVarEntry *TICALL ticalc_check_if_var_exists(TNode * tree,
     return NULL;
 
   if (tree->data == NULL) {	// old format
-    vars = t_node_nth_child(tree, 0);
+    vars = g_node_nth_child(tree, 0);
     if (vars == NULL)
       return NULL;
   } else {			// new format
@@ -223,17 +218,17 @@ TIEXPORT TiVarEntry *TICALL ticalc_check_if_var_exists(TNode * tree,
       return 0;
   }
 
-  for (i = 0; i < (int)t_node_n_children(vars); i++)	// parse folders
+  for (i = 0; i < g_node_n_children(vars); i++)	// parse folders
   {
-    TNode *parent = t_node_nth_child(vars, i);
+    GNode *parent = g_node_nth_child(vars, i);
     TiVarEntry *fe = (TiVarEntry *) (parent->data);
 
     if ((fe != NULL) && strcmp(fe->name, fldname))
       continue;
 
-    for (j = 0; j < (int)t_node_n_children(parent); j++)	//parse variables
+    for (j = 0; j < g_node_n_children(parent); j++)	//parse variables
     {
-      TNode *child = t_node_nth_child(parent, j);
+      GNode *child = g_node_nth_child(parent, j);
       TiVarEntry *ve = (TiVarEntry *) (child->data);
 
       if (!strcmp(ve->name, varname))
@@ -255,7 +250,7 @@ TIEXPORT TiVarEntry *TICALL ticalc_check_if_app_exists(TNode * tree,
     return NULL;
 
   if (tree->data == NULL) {	// old format
-    apps = t_node_nth_child(tree, 1);
+    apps = g_node_nth_child(tree, 1);
     if (apps == NULL)
       return NULL;
   } else {			// new format
@@ -264,8 +259,8 @@ TIEXPORT TiVarEntry *TICALL ticalc_check_if_app_exists(TNode * tree,
       return 0;
   }
 
-  for (i = 0; i < (int)t_node_n_children(apps); i++) {
-    TNode *child = t_node_nth_child(apps, i);
+  for (i = 0; i < g_node_n_children(apps); i++) {
+    GNode *child = g_node_nth_child(apps, i);
 
     TiVarEntry *ve = (TiVarEntry *) (child->data);
 
@@ -288,7 +283,7 @@ TIEXPORT int TICALL ticalc_dirlist_numvars(TNode * tree)
 
   // List variables
   if (tree->data == NULL) {	// old format
-    vars = t_node_nth_child(tree, 0);
+    vars = g_node_nth_child(tree, 0);
     if (vars == NULL)
       return 0;
   } else {			// new format
@@ -297,11 +292,11 @@ TIEXPORT int TICALL ticalc_dirlist_numvars(TNode * tree)
       return 0;
   }
 
-  for (i = 0; i < (int)t_node_n_children(vars); i++)	// parse folders
+  for (i = 0; i < g_node_n_children(vars); i++)	// parse folders
   {
-    TNode *parent = t_node_nth_child(vars, i);
+    GNode *parent = g_node_nth_child(vars, i);
 
-    for (j = 0; j < (int)t_node_n_children(parent); j++)	//parse variables
+    for (j = 0; j < g_node_n_children(parent); j++)	//parse variables
     {
       nvars++;
     }
@@ -321,17 +316,17 @@ TIEXPORT int TICALL ticalc_dirlist_memused(TNode * tree)
     return 0;
 
   // List variables
-  vars = t_node_nth_child(tree, 0);
+  vars = g_node_nth_child(tree, 0);
   if (vars == NULL)
     return 0;
 
-  for (i = 0; i < (int)t_node_n_children(vars); i++)	// parse folders
+  for (i = 0; i < g_node_n_children(vars); i++)	// parse folders
   {
-    TNode *parent = t_node_nth_child(vars, i);
+    GNode *parent = g_node_nth_child(vars, i);
 
-    for (j = 0; j < (int)t_node_n_children(parent); j++)	//parse variables
+    for (j = 0; j < g_node_n_children(parent); j++)	//parse variables
     {
-      TNode *child = t_node_nth_child(parent, j);
+      GNode *child = g_node_nth_child(parent, j);
       TiVarEntry *ve = (TiVarEntry *) (child->data);
 
       mem += ve->size;
@@ -387,29 +382,24 @@ int tixx_directorylist2(TNode ** vars, TNode ** apps, uint32_t * memory)
   TNode *var_node, *app_node;
   int err;
 
-  // Get old directory list
+  *vars = g_node_new("Variables");
+  *apps = g_node_new("Applications");
+
   err = tcf->directorylist(&tree, memory);
   if (err) {
     *vars = *apps = NULL;
     return err;
   }
 
-  // Get Vars tree
-  var_node = t_node_nth_child(tree, 0);
-  var_node->data = strdup(VAR_NODE_NAME); // so that it can be freed !
+  var_node = *vars = g_node_nth_child(tree, 0);
+  var_node->data = VAR_NODE_NAME;
 
-  // Get Apps tree
-  app_node = t_node_nth_child(tree, 1);
-  app_node->data = strdup(APP_NODE_NAME);
+  app_node = *apps = g_node_nth_child(tree, 1);
+  app_node->data = APP_NODE_NAME;
 
-  // Split trees
-  t_node_unlink(var_node);
-  t_node_unlink(app_node);
-  t_node_destroy(tree);
-
-  // Returns new trees
-  *vars = var_node;
-  *apps = app_node;
+  g_node_unlink(var_node);
+  g_node_unlink(app_node);
+  g_node_destroy(tree);
 
   return 0;
 }
