@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: error.c 1926 2006-02-25 13:46:26Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,11 +19,10 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "gettext.h"
-
 #include "calc_err.h"
 #include "headers.h"
 #include "update.h"
+#include "intl2.h"
 
 extern TicableLinkCable *cable;
 
@@ -60,7 +56,7 @@ TIEXPORT int TICALL ticalc_get_error(int err_num, char *error_msg)
     strcat(error_msg, "\n");
     strcat(error_msg,
 	   _
-	   ("Cause: the calculator is busy. Return to HOME.."));
+	   ("Cause: the calculator is off, your link cable is not plugged correctly, your calculator is busy, ..."));
     break;
 
   case ERR_VOID_FUNCTION:
