@@ -1,8 +1,6 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: intrface.c 1413 2005-07-21 17:03:13Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,13 +17,6 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-#if HAVE_LOCALE_H
-#include <locale.h>
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -33,15 +24,13 @@
 #include <windows.h>
 #endif
 
-#include "gettext.h"
-
+#include "intl2.h"
 #include "headers.h"
 #include "calc_ver.h"
 #include "calc_err.h"
 #include "calc_def.h"
 #include "tixx.h"
 #include "type2str.h"
-#include "printl.h"
 
 /*****************/
 /* Internal data */
@@ -56,63 +45,45 @@ int lock = 0;
 /* Entry points */
 /****************/
 
-// not static, must be shared between instances
-int ticalcs_instance = 0;	// counts # of instances
-
 /*
   This function should be the first one to call.
 */
 TIEXPORT int TICALL ticalc_init()
 {
-	char locale_dir[65536];
 #ifdef __WIN32__
-	HANDLE hDll;
-  	int i;
-  	
-  	// Get library path
-  	hDll = GetModuleHandle("ticables.dll");
-  	GetModuleFileName(hDll, locale_dir, 65535);
-  	
-  	for (i = strlen(locale_dir); i >= 0; i--) {
-    		if (locale_dir[i] == '\\')
-      			break;
-  	}
-  	
-  	locale_dir[i] = '\0';
-  	strcat(locale_dir, "\\locale");
-#else
-	strcpy(locale_dir, LOCALEDIR);
+  HANDLE hDll;
+  char LOCALEDIR[65536];
+  int i;
+  hDll = GetModuleHandle("ticables.dll");
+  GetModuleFileName(hDll, LOCALEDIR, 65535);
+  for (i = strlen(LOCALEDIR); i >= 0; i--) {
+    if (LOCALEDIR[i] == '\\')
+      break;
+  }
+  LOCALEDIR[i] = '\0';
+  strcat(LOCALEDIR, "\\locale");
 #endif
 
-	if (ticalcs_instance)
-		return (++ticalcs_instance);
-	printl2(0, _("ticalcs library version %s\n"), LIBTICALCS_VERSION);
+  tifiles_init();
 
 #if defined(ENABLE_NLS)
-	// Init i18n support
-	printl2(0, "setlocale: <%s>\n", setlocale(LC_ALL, ""));
-  	printl2(0, "bindtextdomain: <%s>\n", bindtextdomain(PACKAGE, LOCALEDIR));
-  	//bind_textdomain_codeset(PACKAGE, "UTF-8"/*"ISO-8859-15"*/);
-  	printl2(0, "textdomain: <%s>\n", textdomain(PACKAGE));
+  setlocale(LC_ALL, "");
+  bindtextdomain(PACKAGE, LOCALEDIR);
+  DISPLAY("%s: bindtextdomain to %s\n", PACKAGE, LOCALEDIR);
+  //bind_textdomain_codeset(PACKAGE, "ISO-8859-15");
+  textdomain(PACKAGE);
 #endif
 
-	// Check version
-	if (strcmp(tifiles_get_version(), LIBCALCS_REQUIRES_LIBFILES_VERSION) < 0) {
-    		printl2(0, _("Libtifiles: version mismatches. Library version >= <%s> is required.\n"),
-	    		LIBCALCS_REQUIRES_LIBFILES_VERSION);
-    		exit(-1);
-	}	
-	if (strcmp(ticable_get_version(), LIBCALCS_REQUIRES_LIBCABLES_VERSION) < 0) {
-    		printl2(0, _("Libticables: version mismatches. Library version >= <%s> is required.\n"),
-	    		LIBCALCS_REQUIRES_LIBCABLES_VERSION);
-    		exit(-1);
-	}
+  DISPLAY(_("Libticalcs: version %s\n"), LIBTICALCS_VERSION);
 
-	// Init sub-libraries
-  	tifiles_init();
-  	ticable_init();
+  if (strcmp(tifiles_get_version(), LIB_FILES_VERSION_REQUIRED) < 0) {
+    DISPLAY(_
+	    ("Libtifiles: version mismatches. Library version >= <%s> is required.\n"),
+	    LIB_FILES_VERSION_REQUIRED);
+    exit(-1);
+  }
 
-  	return (++ticalcs_instance);
+  return 0;
 }
 
 /*
@@ -121,10 +92,9 @@ TIEXPORT int TICALL ticalc_init()
 */
 TIEXPORT int TICALL ticalc_exit()
 {
-	ticable_exit();
-  	tifiles_exit();
+  tifiles_exit();
 
-  	return (--ticalcs_instance);
+  return 0;
 }
 
 /***********/
@@ -183,8 +153,8 @@ TIEXPORT void TICALL ticalc_set_calc(TicalcType type, TicalcFncts * calc)
 #endif
 #endif
 
-  printl2(0, _("settings:\n"));
-  printl2(0, _("  calc type: %s\n"),
+  DISPLAY(_("Libticalcs settings...\n"));
+  DISPLAY(_("  Calc type: %s\n"),
 	  tifiles_calctype_to_string(ticalcs_calc_type));
 
   tcf = calc;
@@ -212,14 +182,11 @@ TIEXPORT void TICALL ticalc_set_calc(TicalcType type, TicalcFncts * calc)
     calc->send_flash = ti92_send_flash;
     calc->recv_flash = ti92_recv_flash;
     calc->get_idlist = ti92_get_idlist;
-
-	calc->recv_var_2 = ti92_recv_var_2;
     break;
 
   case CALC_V200:
   case CALC_TI92P:
   case CALC_TI89:
-  case CALC_TI89T:
     calc->supported_operations = ti89_supported_operations;
     calc->is_silent = !0;
     calc->has_folder = !0;
@@ -240,8 +207,6 @@ TIEXPORT void TICALL ticalc_set_calc(TicalcType type, TicalcFncts * calc)
     calc->get_idlist = ti89_get_idlist;
     calc->get_clock = ti89_get_clock;
     calc->set_clock = ti89_set_clock;
-
-	calc->recv_var_2 = ti89_recv_var_2;
     break;
 
   case CALC_TI86:
@@ -263,8 +228,6 @@ TIEXPORT void TICALL ticalc_set_calc(TicalcType type, TicalcFncts * calc)
     calc->send_flash = ti86_send_flash;
     calc->recv_flash = ti86_recv_flash;
     calc->get_idlist = ti86_get_idlist;
-
-	calc->recv_var_2 = ti86_recv_var_2;
     break;
 
   case CALC_TI85:
@@ -286,8 +249,6 @@ TIEXPORT void TICALL ticalc_set_calc(TicalcType type, TicalcFncts * calc)
     calc->send_flash = ti85_send_flash;
     calc->recv_flash = ti85_recv_flash;
     calc->get_idlist = ti85_get_idlist;
-
-	calc->recv_var_2 = ti85_recv_var_2;
     break;
 
   case CALC_TI83:
@@ -309,8 +270,6 @@ TIEXPORT void TICALL ticalc_set_calc(TicalcType type, TicalcFncts * calc)
     calc->send_flash = ti83_send_flash;
     calc->recv_flash = ti83_recv_flash;
     calc->get_idlist = ti83_get_idlist;
-
-	calc->recv_var_2 = ti83_recv_var_2;
     break;
 
   case CALC_TI82:
@@ -332,12 +291,9 @@ TIEXPORT void TICALL ticalc_set_calc(TicalcType type, TicalcFncts * calc)
     calc->send_flash = ti82_send_flash;
     calc->recv_flash = ti82_recv_flash;
     calc->get_idlist = ti82_get_idlist;
-
-	calc->recv_var_2 = ti82_recv_var_2;
     break;
 
-  case CALC_TI84P:
-  case CALC_TI83P:  
+  case CALC_TI83P:
   case CALC_TI73:
     calc->supported_operations = ti73_supported_operations;
     calc->is_silent = !0;
@@ -357,15 +313,15 @@ TIEXPORT void TICALL ticalc_set_calc(TicalcType type, TicalcFncts * calc)
     calc->send_flash = ti73_send_flash;
     calc->recv_flash = ti73_recv_flash;
     calc->get_idlist = ti73_get_idlist;
-
-	calc->recv_var_2 = ti73_recv_var_2;
     break;
 
   default:
-    printl2(2, _("Function not implemented. This is a bug. Please report it."));
-    printl2(2, _("Informations:\n"));
-    printl2(2, _("Calc: %i\n"), type);
-    printl2(2, _("Program halted before crashing...\n"));
+    fprintf(stderr,
+	    _
+	    ("Function not implemented. This is a bug. Please report it."));
+    DISPLAY_ERROR(_("Informations:\n"));
+    DISPLAY_ERROR(_("Calc: %i\n"), type);
+    DISPLAY_ERROR(_("Program halted before crashing...\n"));
     exit(-1);
     break;
   }
