@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: ti73.c 1397 2005-07-20 10:55:03Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,16 +17,15 @@
  */
 
 /*
-  This unit provides TI73/TI83+/TI84+ support.
+  This unit provides TI73/TI83+ support.
 */
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-//#include <unistd.h>
-
-#include "gettext.h"
+#include <unistd.h>
 
+#include "intl2.h"
 #include "headers.h"
 #include "externs.h"
 #include "update.h"
@@ -38,11 +34,6 @@
 #include "cmd73.h"
 #include "rom83p.h"
 #include "pause.h"
-#include "printl.h"
-
-#ifdef __WIN32__
-#pragma warning( disable : 4761 4244)
-#endif
 
 // Screen coordinates of the TI83+
 #define TI73_ROWS  64
@@ -64,7 +55,7 @@ int ti73_isready(void)
 {
   uint16_t status;
 
-  printl2(0, _("Is calculator ready ?\n"));
+  DISPLAY(_("Is calculator ready ?\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -98,7 +89,7 @@ int ti73_directorylist(TNode ** tree, uint32_t * memory)
   uint16_t unused;
   TNode *vars, *apps, *folder;
 
-  printl2(0, _("Directory listing...\n"));
+  DISPLAY(_("Directory listing...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -111,14 +102,14 @@ int ti73_directorylist(TNode ** tree, uint32_t * memory)
   fixup(*memory);
   TRYF(ti73_send_ACK());
 
-  *tree = t_node_new(NULL);
-  vars = t_node_new(NULL);
-  apps = t_node_new(NULL);
-  t_node_append(*tree, vars);
-  t_node_append(*tree, apps);
+  *tree = g_node_new(NULL);
+  vars = g_node_new(NULL);
+  apps = g_node_new(NULL);
+  g_node_append(*tree, vars);
+  g_node_append(*tree, apps);
 
-  folder = t_node_new(NULL);
-  t_node_append(vars, folder);
+  folder = g_node_new(NULL);
+  g_node_append(vars, folder);
 
   for (;;) {
     TiVarEntry *ve = calloc(1, sizeof(TiVarEntry));
@@ -136,11 +127,11 @@ int ti73_directorylist(TNode ** tree, uint32_t * memory)
       return err;
 
     tifiles_translate_varname(ve->name, ve->trans, ve->type);
-    node = t_node_new(ve);
+    node = g_node_new(ve);
     if (ve->type != TI73_APPL)
-      t_node_append(folder, node);
+      g_node_append(folder, node);
     else
-      t_node_append(apps, node);
+      g_node_append(apps, node);
 
     sprintf(update->label_text, _("Reading of '%s'"), ve->trans);
     update_label();
@@ -160,7 +151,7 @@ int ti73_screendump(uint8_t ** bitmap, int mask_mode,
   uint16_t max_cnt;
   int err;
 
-  printl2(0, _("Receiving screendump...\n"));
+  DISPLAY(_("Receiving screendump...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -176,7 +167,7 @@ int ti73_screendump(uint8_t ** bitmap, int mask_mode,
   (*bitmap) =
       (uint8_t *) malloc(TI73_COLS * TI73_ROWS * sizeof(uint8_t) / 8);
   if ((*bitmap) == NULL) {
-    printl2(2, "Unable to allocate memory.\n");
+    fprintf(stderr, "Unable to allocate memory.\n");
     exit(0);
   }
 
@@ -188,7 +179,7 @@ int ti73_screendump(uint8_t ** bitmap, int mask_mode,
   TRYF(err)};
   TRYF(ti73_send_ACK());
 
-  printl2(0, _("Done.\n"));
+  DISPLAY(_("Done.\n"));
 
   TRYF(cable->close());
   UNLOCK_TRANSFER();
@@ -203,7 +194,7 @@ int ti73_recv_backup(const char *filename, int mask_mode)
   uint8_t varname[9] = { 0 };
   uint8_t attr;
 
-  printl2(0, _("Receiving backup...\n"));
+  DISPLAY(_("Receiving backup...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -219,7 +210,7 @@ int ti73_recv_backup(const char *filename, int mask_mode)
   TRYF(ti73_recv_ACK(NULL));
 
   TRYF(ti73_recv_VAR
-       (&content->data_length1, &content->type, (char*)varname, &attr));
+       (&content->data_length1, &content->type, varname, &attr));
   content->data_length2 = varname[0] | (varname[1] << 8);
   content->data_length3 = varname[2] | (varname[3] << 8);
   content->mem_address = varname[4] | (varname[5] << 8);
@@ -260,7 +251,7 @@ int ti73_send_backup(const char *filename, int mask_mode)
   uint8_t varname[9];
   uint8_t rej_code;
 
-  printl2(0, _("Sending backup...\n"));
+  DISPLAY(_("Sending backup...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -279,7 +270,7 @@ int ti73_send_backup(const char *filename, int mask_mode)
   varname[4] = LSB(content.mem_address);
   varname[5] = MSB(content.mem_address);
 
-  TRYF(ti73_send_RTS(content.data_length1, TI73_BKUP, (char*)varname, 0x00));
+  TRYF(ti73_send_RTS(content.data_length1, TI73_BKUP, varname, 0x00));
   TRYF(ti73_recv_ACK(NULL));
 
   TRYF(ti73_recv_SKIP(&rej_code))
@@ -323,7 +314,7 @@ int ti73_recv_var(char *filename, int mask_mode, TiVarEntry * entry)
   char *fn;
   static int nvar = 0;
 
-  printl2(0, _("Receiving variable(s)...\n"));
+  DISPLAY(_("Receiving variable(s)...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -394,7 +385,7 @@ int ti73_send_var(const char *filename, int mask_mode, char **actions)
   uint8_t rej_code;
   uint8_t attrb;
 
-  printl2(0, _("Sending variable(s)...\n"));
+  DISPLAY(_("Sending variable(s)...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -410,16 +401,16 @@ int ti73_send_var(const char *filename, int mask_mode, char **actions)
     uint8_t varname[18];
 
     if (actions == NULL)	// backup or old behaviour
-      strcpy((char*)varname, entry->name);
+      strcpy(varname, entry->name);
     else if (actions[i][0] == ACT_SKIP) {
-      printl2(0, _(" '%s' has been skipped !\n"), entry->name);
+      DISPLAY(_(" '%s' has been skipped !\n"), entry->name);
       continue;
     } else if (actions[i][0] == ACT_OVER)
-      strcpy((char*)varname, actions[i] + 1);
+      strcpy(varname, actions[i] + 1);
 
     attrb = (mask_mode & MODE_SEND_TO_FLASH) ?
 	ATTRB_ARCHIVED : entry->attr;
-    TRYF(ti73_send_RTS(entry->size, entry->type, (char*)varname, attrb));
+    TRYF(ti73_send_RTS(entry->size, entry->type, varname, attrb));
     TRYF(ti73_recv_ACK(NULL));
 
     TRYF(ti73_recv_SKIP(&rej_code));
@@ -445,7 +436,7 @@ int ti73_send_var(const char *filename, int mask_mode, char **actions)
     TRYF(ti73_send_XDP(entry->size, entry->data));
     TRYF(ti73_recv_ACK(NULL));
 
-    printl2(0, "\n");
+    DISPLAY("\n");
   }
 
   TRYF(ti73_send_EOT());
@@ -456,17 +447,12 @@ int ti73_send_var(const char *filename, int mask_mode, char **actions)
   return 0;
 }
 
-int ti73_recv_var_2(char *filename, int mask_mode, TiVarEntry * entry)
-{
-	return ERR_VOID_FUNCTION;
-}
-
 int ti73_send_flash(const char *filename, int mask_mode)
 {
   Ti8xFlash content = { 0 };
   int i;
 
-  printl2(0, _("Sending FLASH app/os...\n"));
+  DISPLAY(_("Sending FLASH app/os...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -475,6 +461,23 @@ int ti73_send_flash(const char *filename, int mask_mode)
   sprintf(update->label_text, ("Sending FLASH OS/App..."));
   update_label();
 
+  if (mask_mode & MODE_APPS) {	// inform TI that a FLASH app is about to be sent
+    uint16_t length;
+    uint8_t buffer[16];
+
+    TRYF(ti73_send_FLSH());
+    TRYF(ti73_recv_ACK(NULL));
+
+    TRYF(ti73_send_CTS());
+    TRYF(ti73_recv_ACK(NULL));
+
+    TRYF(ti73_recv_XDP(&length, (uint8_t *) buffer));	// ??
+    TRYF(ti73_send_ACK());
+
+    //TRYF(ti73_send_RDY());
+    //TRYF(ti73_recv_ACK(NULL));
+  }
+
   TRYF(ti8x_read_flash_file(filename, &content));
 
   for (i = 0; i < content.num_pages; i++) {
@@ -490,13 +493,10 @@ int ti73_send_flash(const char *filename, int mask_mode)
     TRYF(ti73_send_XDP(fp->length, fp->data));
     TRYF(ti73_recv_ACK(NULL));
 
-	if(ticalcs_calc_type != CALC_TI84P)
-	{
-		if (i == 1)
-		  PAUSE(1000);		// This pause is NEEDED !
-		if (i == content.num_pages - 2)
-		  PAUSE(2500);		// This pause is NEEDED !
-	}
+    if (i == 1)
+      PAUSE(1000);		// This pause is NEEDED !
+    if (i == content.num_pages - 2)
+      PAUSE(2500);		// This pause is NEEDED !
 
     update->main_percentage = (float) i / content.num_pages;
     if (update->cancel)
@@ -518,10 +518,7 @@ int ti73_recv_flash(const char *filename, int mask_mode, TiVarEntry * ve)
   int npages;
   uint32_t size = 0;
 
-  if(ticalcs_calc_type == CALC_TI84P)
-	return ERR_VOID_FUNCTION;
-
-  printl2(0, _("Receiving FLASH application...\n"));
+  DISPLAY(_("Receiving FLASH application...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -580,8 +577,8 @@ exit:
   return 0;
 }
 
-#define DUMP_ROM73_FILE "dumprom.8Xp"
-//#define ROMSIZE 512		// 512KB (TI83+) or 1MB (TI84+) or 2MB (SilverEdition)
+#define DUMP_ROM73_FILE "dumprom.83p"
+#define ROMSIZE 512		// 512KB
 
 int ti73_dump_rom(const char *filename, int mask_mode)
 {
@@ -594,10 +591,9 @@ int ti73_dump_rom(const char *filename, int mask_mode)
   FILE *f, *file;
   uint16_t checksum, sum;
   int err;
-  int b = 0;
-  int ROMSIZE = (mask_mode == ROM_SE) ? 2048 : (ticalcs_calc_type == CALC_TI84P) ? 1024 : 512;
+  int b = 0;;
 
-  printl2(0, _("ROM dumping...\n"));
+  DISPLAY(_("ROM dumping...\n"));
 
   // Copies ROM dump program into a file
   f = fopen(DUMP_ROM73_FILE, "wb");
@@ -695,7 +691,7 @@ int ti73_get_idlist(char *id)
   uint8_t varname[9];
   uint8_t varattr;
 
-  printl2(0, _("Getting ID list...\n"));
+  DISPLAY(_("Getting ID list...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -707,14 +703,14 @@ int ti73_get_idlist(char *id)
   TRYF(ti73_send_REQ(0x0000, TI73_IDLIST, "", 0x00));
   TRYF(ti73_recv_ACK(&unused));
 
-  TRYF(ti73_recv_VAR((uint16_t *) & varsize, &vartype, (char*)varname, &varattr));
+  TRYF(ti73_recv_VAR((uint16_t *) & varsize, &vartype, varname, &varattr));
   fixup(varsize);
   TRYF(ti73_send_ACK());
 
   TRYF(ti73_send_CTS());
   TRYF(ti73_recv_ACK(NULL));
 
-  TRYF(ti73_recv_XDP(&varsize, (uint8_t *)id));
+  TRYF(ti73_recv_XDP((uint16_t *) & varsize, id));
   id[varsize] = '\0';
   TRYF(ti73_send_ACK());
 
