@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: ti83.c 1397 2005-07-20 10:55:03Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,8 +26,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include "gettext.h"
-
+#include "intl2.h"
 #include "headers.h"
 #include "externs.h"
 #include "update.h"
@@ -39,11 +35,6 @@
 #include "cmd82.h"
 #include "rom83.h"
 #include "pause.h"
-#include "printl.h"
-
-#ifdef __WIN32__
-#pragma warning( disable : 4761 4244 )
-#endif
 
 // Screen coordinates of the TI83
 #define TI83_ROWS  64
@@ -73,7 +64,7 @@ int ti83_directorylist(TNode ** tree, uint32_t * memory)
   uint16_t unused;
   TNode *vars, *apps, *folder;
 
-  printl2(0, _("Directory listing...\n"));
+  DISPLAY(_("Directory listing...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -86,14 +77,14 @@ int ti83_directorylist(TNode ** tree, uint32_t * memory)
   fixup(*memory);
   TRYF(ti82_send_ACK());
 
-  *tree = t_node_new(NULL);
-  vars = t_node_new(NULL);
-  apps = t_node_new(NULL);
-  t_node_append(*tree, vars);
-  t_node_append(*tree, apps);
+  *tree = g_node_new(NULL);
+  vars = g_node_new(NULL);
+  apps = g_node_new(NULL);
+  g_node_append(*tree, vars);
+  g_node_append(*tree, apps);
 
-  folder = t_node_new(NULL);
-  t_node_append(vars, folder);
+  folder = g_node_new(NULL);
+  g_node_append(vars, folder);
 
   for (;;) {
     TiVarEntry *ve = calloc(1, sizeof(TiVarEntry));
@@ -109,8 +100,8 @@ int ti83_directorylist(TNode ** tree, uint32_t * memory)
       return err;
 
     tifiles_translate_varname(ve->name, ve->trans, ve->type);
-    node = t_node_new(ve);
-    t_node_append(folder, node);
+    node = g_node_new(ve);
+    g_node_append(folder, node);
 
     sprintf(update->label_text, _("Reading of '%s'"), ve->trans);
     update_label();
@@ -130,7 +121,7 @@ int ti83_screendump(uint8_t ** bitmap, int mask_mode,
   uint16_t max_cnt;
   int err;
 
-  printl2(0, _("Receiving screendump...\n"));
+  DISPLAY(_("Receiving screendump...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -146,7 +137,7 @@ int ti83_screendump(uint8_t ** bitmap, int mask_mode,
   (*bitmap) =
       (uint8_t *) malloc(TI83_COLS * TI83_ROWS * sizeof(uint8_t) / 8);
   if ((*bitmap) == NULL) {
-    printl2(2, "Unable to allocate memory.\n");
+    fprintf(stderr, "Unable to allocate memory.\n");
     exit(0);
   }
 
@@ -158,7 +149,7 @@ int ti83_screendump(uint8_t ** bitmap, int mask_mode,
   TRYF(err)};
   TRYF(ti82_send_ACK());
 
-  printl2(0, _("Done.\n"));
+  DISPLAY(_("Done.\n"));
 
   TRYF(cable->close());
   UNLOCK_TRANSFER();
@@ -173,7 +164,7 @@ int ti83_recv_backup(const char *filename, int mask_mode)
   uint8_t varname[9] = { 0 };
   uint16_t unused;
 
-  printl2(0, _("Receiving backup...\n"));
+  DISPLAY(_("Receiving backup...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -188,7 +179,7 @@ int ti83_recv_backup(const char *filename, int mask_mode)
   TRYF(ti82_send_REQ(0x0000, TI83_BKUP, ""));
   TRYF(ti82_recv_ACK(&unused));
 
-  TRYF(ti82_recv_VAR(&(content->data_length1), &content->type, (char*)varname));
+  TRYF(ti82_recv_VAR(&(content->data_length1), &content->type, varname));
   content->data_length2 = varname[0] | (varname[1] << 8);
   content->data_length3 = varname[2] | (varname[3] << 8);
   content->mem_address = varname[4] | (varname[5] << 8);
@@ -229,7 +220,7 @@ int ti83_send_backup(const char *filename, int mask_mode)
   uint8_t rej_code;
   uint16_t status;
 
-  printl2(0, _("Sending backup...\n"));
+  DISPLAY(_("Sending backup...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -248,7 +239,7 @@ int ti83_send_backup(const char *filename, int mask_mode)
   varname[4] = LSB(content.mem_address);
   varname[5] = MSB(content.mem_address);
 
-  TRYF(ti82_send_RTS(content.data_length1, TI83_BKUP, (char*)varname));
+  TRYF(ti82_send_RTS(content.data_length1, TI83_BKUP, varname));
   TRYF(ti82_recv_ACK(&status));
 
   TRYF(ti82_recv_SKIP(&rej_code))
@@ -293,7 +284,7 @@ int ti83_recv_var(char *filename, int mask_mode, TiVarEntry * entry)
   char *fn;
   static int nvar = 0;
 
-  printl2(0, _("Receiving variable(s)...\n"));
+  DISPLAY(_("Receiving variable(s)...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -363,7 +354,7 @@ int ti83_send_var(const char *filename, int mask_mode, char **actions)
   uint8_t rej_code;
   uint16_t status;
 
-  printl2(0, _("Sending variable(s)...\n"));
+  DISPLAY(_("Sending variable(s)...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -379,14 +370,14 @@ int ti83_send_var(const char *filename, int mask_mode, char **actions)
     uint8_t varname[18];
 
     if (actions == NULL)	// backup or old behaviour
-      strcpy((char*)varname, entry->name);
+      strcpy(varname, entry->name);
     else if (actions[i][0] == ACT_SKIP) {
-      printl2(0, _(" '%s' has been skipped !\n"), entry->name);
+      DISPLAY(_(" '%s' has been skipped !\n"), entry->name);
       continue;
     } else if (actions[i][0] == ACT_OVER)
-      strcpy((char*)varname, actions[i] + 1);
+      strcpy(varname, actions[i] + 1);
 
-    TRYF(ti82_send_RTS(entry->size, entry->type, (char*)varname));
+    TRYF(ti82_send_RTS(entry->size, entry->type, varname));
     TRYF(ti82_recv_ACK(&status));
 
     TRYF(ti82_recv_SKIP(&rej_code));
@@ -412,7 +403,7 @@ int ti83_send_var(const char *filename, int mask_mode, char **actions)
     TRYF(ti82_send_XDP(entry->size, entry->data));
     TRYF(ti82_recv_ACK(&status));
 
-    printl2(0, "\n");
+    DISPLAY("\n");
   }
 
   TRYF(cable->close());
@@ -423,11 +414,6 @@ int ti83_send_var(const char *filename, int mask_mode, char **actions)
   return 0;
 }
 
-int ti83_recv_var_2(char *filename, int mask_mode, TiVarEntry * entry)
-{
-	return ERR_VOID_FUNCTION;
-}
-
 int ti83_send_flash(const char *filename, int mask_mode)
 {
   return ERR_VOID_FUNCTION;
@@ -454,7 +440,7 @@ int ti83_dump_rom(const char *filename, int mask_mode)
   int err;
   int b = 0;;
 
-  printl2(0, _("ROM dumping...\n"));
+  DISPLAY(_("ROM dumping...\n"));
 
   // Copies ROM dump program into a file
   f = fopen(DUMP_ROM83_FILE, "wb");
