@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: ti85.c 1397 2005-07-20 10:55:03Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,8 +26,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include "gettext.h"
-
+#include "intl2.h"
 #include "headers.h"
 #include "externs.h"
 #include "update.h"
@@ -39,11 +35,6 @@
 #include "cmd85.h"
 #include "rom85u.h"
 #include "rom85z.h"
-#include "printl.h"
-
-#ifdef __WIN32__
-#pragma warning( disable : 4761 4244)
-#endif
 
 // Screen coordinates of the TI82
 #define TI85_ROWS  64
@@ -78,7 +69,7 @@ int ti85_screendump(uint8_t ** bitmap, int mask_mode,
   uint16_t max_cnt;
   int err;
 
-  printl2(0, _("Receiving screendump...\n"));
+  DISPLAY(_("Receiving screendump...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -94,7 +85,7 @@ int ti85_screendump(uint8_t ** bitmap, int mask_mode,
   (*bitmap) =
       (uint8_t *) malloc(TI85_COLS * TI85_ROWS * sizeof(uint8_t) / 8);
   if ((*bitmap) == NULL) {
-    printl2(2, "Unable to allocate memory.\n");
+    fprintf(stderr, "Unable to allocate memory.\n");
     exit(0);
   }
 
@@ -106,7 +97,7 @@ int ti85_screendump(uint8_t ** bitmap, int mask_mode,
   TRYF(err)};
   TRYF(ti85_send_ACK());
 
-  printl2(0, _("Done.\n"));
+  DISPLAY(_("Done.\n"));
 
   TRYF(cable->close());
   UNLOCK_TRANSFER();
@@ -120,7 +111,7 @@ int ti85_recv_backup(const char *filename, int mask_mode)
   Ti8xBackup *content;
   uint8_t varname[9] = { 0 };
 
-  printl2(0, _("Receiving backup...\n"));
+  DISPLAY(_("Receiving backup...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -131,7 +122,7 @@ int ti85_recv_backup(const char *filename, int mask_mode)
   sprintf(update->label_text, _("Waiting for backup..."));
   update_label();
 
-  TRYF(ti85_recv_VAR(&(content->data_length1), &content->type, (char*)varname));
+  TRYF(ti85_recv_VAR(&(content->data_length1), &content->type, varname));
   content->data_length2 = varname[0] | (varname[1] << 8);
   content->data_length3 = varname[2] | (varname[3] << 8);
   content->mem_address = varname[4] | (varname[5] << 8);
@@ -173,7 +164,7 @@ int ti85_send_backup(const char *filename, int mask_mode)
   uint8_t rej_code;
   uint16_t status;
 
-  printl2(0, _("Sending backup...\n"));
+  DISPLAY(_("Sending backup...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -191,7 +182,7 @@ int ti85_send_backup(const char *filename, int mask_mode)
   varname[3] = MSB(content.data_length3);
   varname[4] = LSB(content.mem_address);
   varname[5] = MSB(content.mem_address);
-  TRYF(ti85_send_VAR(content.data_length1, TI85_BKUP, (char*)varname));
+  TRYF(ti85_send_VAR(content.data_length1, TI85_BKUP, varname));
   TRYF(ti85_recv_ACK(&status));
 
   sprintf(update->label_text, _("Waiting user's action..."));
@@ -243,7 +234,7 @@ int ti85_recv_var(char *filename, int mask_mode, TiVarEntry * unused)
   int err = 0;
   char *fn = NULL;
 
-  printl2(0, _("Receiving variable(s)...\n"));
+  DISPLAY(_("Receiving variable(s)...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -317,7 +308,7 @@ int ti85_send_var(const char *filename, int mask_mode)
   uint8_t rej_code;
   uint16_t status;
 
-  printl2(0, _("Sending variable(s)...\n"));
+  DISPLAY(_("Sending variable(s)...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -364,7 +355,7 @@ int ti85_send_var(const char *filename, int mask_mode)
     TRYF(ti85_send_XDP(entry->size, entry->data));
     TRYF(ti85_recv_ACK(&status));
 
-    printl2(0, "\n");
+    DISPLAY("\n");
   }
 
   if ((mask_mode & MODE_SEND_ONE_VAR) || (mask_mode & MODE_SEND_LAST_VAR)) {
@@ -378,11 +369,6 @@ int ti85_send_var(const char *filename, int mask_mode)
   return 0;
 }
 
-int ti85_recv_var_2(char *filename, int mask_mode, TiVarEntry * entry)
-{
-	return ERR_VOID_FUNCTION;
-}
-
 int ti85_send_flash(const char *filename, int mask_mode)
 {
   return ERR_VOID_FUNCTION;
@@ -409,7 +395,7 @@ int ti85_dump_rom(const char *filename, int mask_mode)
   int err;
   int b = 0;
 
-  printl2(0, _("ROM dumping...\n"));
+  DISPLAY(_("ROM dumping...\n"));
 
   // Copies ROM dump program into a file
   f = fopen(DUMP_ROM85_FILE, "wb");
