@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: ti86.c 1397 2005-07-20 10:55:03Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,8 +26,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include "gettext.h"
-
+#include "intl2.h"
 #include "headers.h"
 #include "externs.h"
 #include "update.h"
@@ -39,11 +35,6 @@
 #include "cmd85.h"
 #include "rom86.h"
 #include "pause.h"
-#include "printl.h"
-
-#ifdef __WIN32__
-#pragma warning( disable : 4761 4244)
-#endif
 
 // Screen coordinates of the TI86
 #define TI86_ROWS  64
@@ -84,7 +75,7 @@ int ti86_directorylist(TNode ** tree, uint32_t * memory)
   uint8_t *mem = (uint8_t *) memory;
   uint8_t hl, ll, lh;
 
-  printl2(0, _("Directory listing...\n"));
+  DISPLAY(_("Directory listing...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -101,14 +92,14 @@ int ti86_directorylist(TNode ** tree, uint32_t * memory)
   lh = mem[2];
   *memory = (hl << 16) | (lh << 8) | ll;
 
-  *tree = t_node_new(NULL);
-  vars = t_node_new(NULL);
-  apps = t_node_new(NULL);
-  t_node_append(*tree, vars);
-  t_node_append(*tree, apps);
+  *tree = g_node_new(NULL);
+  vars = g_node_new(NULL);
+  apps = g_node_new(NULL);
+  g_node_append(*tree, vars);
+  g_node_append(*tree, apps);
 
-  folder = t_node_new(NULL);
-  t_node_append(vars, folder);
+  folder = g_node_new(NULL);
+  g_node_append(vars, folder);
 
   for (;;) {
     TiVarEntry *ve = calloc(1, sizeof(TiVarEntry));
@@ -124,8 +115,8 @@ int ti86_directorylist(TNode ** tree, uint32_t * memory)
       return err;
 
     tifiles_translate_varname(ve->name, ve->trans, ve->type);
-    node = t_node_new(ve);
-    t_node_append(folder, node);
+    node = g_node_new(ve);
+    g_node_append(folder, node);
 
     sprintf(update->label_text, _("Reading of '%s'"), ve->trans);
     update_label();
@@ -145,7 +136,7 @@ int ti86_screendump(uint8_t ** bitmap, int mask_mode,
   uint16_t max_cnt;
   int err;
 
-  printl2(0, _("Receiving screendump...\n"));
+  DISPLAY(_("Receiving screendump...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -161,7 +152,7 @@ int ti86_screendump(uint8_t ** bitmap, int mask_mode,
   (*bitmap) =
       (uint8_t *) malloc(TI86_COLS * TI86_ROWS * sizeof(uint8_t) / 8);
   if ((*bitmap) == NULL) {
-    printl2(2, "Unable to allocate memory.\n");
+    fprintf(stderr, "Unable to allocate memory.\n");
     exit(0);
   }
 
@@ -173,7 +164,7 @@ int ti86_screendump(uint8_t ** bitmap, int mask_mode,
   TRYF(err)};
   TRYF(ti85_send_ACK());
 
-  printl2(0, _("Done.\n"));
+  DISPLAY(_("Done.\n"));
 
   TRYF(cable->close());
   UNLOCK_TRANSFER();
@@ -187,7 +178,7 @@ int ti86_recv_backup(const char *filename, int mask_mode)
   Ti8xBackup *content;
   uint8_t varname[9] = { 0 };
 
-  printl2(0, _("Receiving backup...\n"));
+  DISPLAY(_("Receiving backup...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -198,7 +189,7 @@ int ti86_recv_backup(const char *filename, int mask_mode)
   sprintf(update->label_text, _("Waiting backup..."));
   update_label();
 
-  TRYF(ti85_recv_VAR(&(content->data_length1), &content->type, (char*)varname));
+  TRYF(ti85_recv_VAR(&(content->data_length1), &content->type, varname));
   content->data_length2 = varname[0] | (varname[1] << 8);
   content->data_length3 = varname[2] | (varname[3] << 8);
   content->data_length4 = varname[4] | (varname[5] << 8);
@@ -248,7 +239,7 @@ int ti86_send_backup(const char *filename, int mask_mode)
   uint8_t rej_code;
   uint16_t status;
 
-  printl2(0, _("Sending backup...\n"));
+  DISPLAY(_("Sending backup...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -267,7 +258,7 @@ int ti86_send_backup(const char *filename, int mask_mode)
   varname[4] = LSB(content.data_length4);
   varname[5] = MSB(content.data_length4);
 
-  TRYF(ti85_send_VAR(content.data_length1, TI86_BKUP, (char*)varname));
+  TRYF(ti85_send_VAR(content.data_length1, TI86_BKUP, varname));
   TRYF(ti85_recv_ACK(&status));
 
   sprintf(update->label_text, _("Waiting user's action..."));
@@ -324,7 +315,7 @@ int ti86_recv_var(char *filename, int mask_mode, TiVarEntry * entry)
   char *fn;
   static int nvar = 0;
 
-  printl2(0, _("Receiving variable(s)...\n"));
+  DISPLAY(_("Receiving variable(s)...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -394,7 +385,7 @@ int ti86_send_var(const char *filename, int mask_mode, char **actions)
   uint8_t rej_code;
   uint16_t status;
 
-  printl2(0, _("Sending variable(s)...\n"));
+  DISPLAY(_("Sending variable(s)...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -410,14 +401,14 @@ int ti86_send_var(const char *filename, int mask_mode, char **actions)
     uint8_t varname[18];
 
     if (actions == NULL)	// backup or old behaviour
-      strcpy((char*)varname, entry->name);
+      strcpy(varname, entry->name);
     else if (actions[i][0] == ACT_SKIP) {
-      printl2(0, _(" '%s' has been skipped !\n"), entry->name);
+      DISPLAY(_(" '%s' has been skipped !\n"), entry->name);
       continue;
     } else if (actions[i][0] == ACT_OVER)
-      strcpy((char*)varname, actions[i] + 1);
+      strcpy(varname, actions[i] + 1);
 
-    TRYF(ti85_send_RTS(entry->size, entry->type, (char*)varname));
+    TRYF(ti85_send_RTS(entry->size, entry->type, varname));
     TRYF(ti85_recv_ACK(&status));
 
     TRYF(ti85_recv_SKIP(&rej_code));
@@ -443,7 +434,7 @@ int ti86_send_var(const char *filename, int mask_mode, char **actions)
     TRYF(ti85_send_XDP(entry->size, entry->data));
     TRYF(ti85_recv_ACK(&status));
 
-    printl2(0, "\n");
+    DISPLAY("\n");
   }
 
   TRYF(cable->close());
@@ -454,11 +445,6 @@ int ti86_send_var(const char *filename, int mask_mode, char **actions)
   return 0;
 }
 
-int ti86_recv_var_2(char *filename, int mask_mode, TiVarEntry * entry)
-{
-	return ERR_VOID_FUNCTION;
-}
-
 int ti86_send_flash(const char *filename, int mask_mode)
 {
   return ERR_VOID_FUNCTION;
@@ -485,7 +471,7 @@ int ti86_dump_rom(const char *filename, int mask_mode)
   int err;
   int b = 0;;
 
-  printl2(0, _("ROM dumping...\n"));
+  DISPLAY(_("ROM dumping...\n"));
 
   // Copies ROM dump program into a file
   f = fopen(DUMP_ROM86_FILE, "wb");
