@@ -1,9 +1,6 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: ti89.c 1926 2006-02-25 13:46:26Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2005  Romain Lievin
- *  Copyright (c) 2005, Christian Walther (patches for Mac OS-X port)
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +18,7 @@
  */
 
 /*
-  This unit provides TI89/TI92+/V200/TI89 Titanium support.
+  This unit provides TI89/TI92+/V200 support.
 */
 
 #include <stdio.h>
@@ -29,8 +26,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include "gettext.h"
-
+#include "intl2.h"
 #include "headers.h"
 #include "externs.h"
 #include "update.h"
@@ -41,7 +37,6 @@
 #include "keys89.h"
 #include "pause.h"
 #include "dirlist.h"
-#include "printl.h"
 
 // Screen coordinates of the TI89
 #define TI89_ROWS          128
@@ -66,7 +61,7 @@ int ti89_isready(void)
 {
   uint16_t status;
 
-  printl2(0, _("Is calculator ready ?\n"));
+  DISPLAY(_("Is calculator ready ?\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -78,7 +73,7 @@ int ti89_isready(void)
   TRYF(cable->close());
   UNLOCK_TRANSFER();
 
-  return (status & 0x0100) ? ERR_NOT_READY : 0;
+  return (status & 0x01) ? ERR_NOT_READY : 0;
 }
 
 int ti89_send_key(uint16_t key)
@@ -101,7 +96,7 @@ int ti89_screendump(uint8_t ** bitmap, int mask_mode,
   uint32_t max_cnt;
   int err;
 
-  printl2(0, _("Receiving screendump...\n"));
+  DISPLAY(_("Receiving screendump...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -111,7 +106,6 @@ int ti89_screendump(uint8_t ** bitmap, int mask_mode,
   sc->height = TI89_ROWS;
   switch (ticalcs_calc_type) {
   case CALC_TI89:
-  case CALC_TI89T:
     sc->clipped_width = TI89_COLS_VISIBLE;
     sc->clipped_height = TI89_ROWS_VISIBLE;
     break;
@@ -127,7 +121,7 @@ int ti89_screendump(uint8_t ** bitmap, int mask_mode,
   (*bitmap) =
       (uint8_t *) malloc(TI89_COLS * TI89_ROWS * sizeof(uint8_t) / 8);
   if ((*bitmap) == NULL) {
-    printl2(2, "Unable to allocate memory.\n");
+    fprintf(stderr, "Unable to allocate memory.\n");
     exit(0);
   }
 
@@ -139,13 +133,13 @@ int ti89_screendump(uint8_t ** bitmap, int mask_mode,
   TRYF(err)};
   TRYF(ti89_send_ACK());
 
-  printl2(0, _("Done.\n"));
+  DISPLAY(_("Done.\n"));
 
   TRYF(cable->close());
   UNLOCK_TRANSFER();
 
   // Clip the unused part of the screen (nethertheless useable witha asm prog)
-  if (((ticalcs_calc_type == CALC_TI89) || (ticalcs_calc_type == CALC_TI89T))
+  if ((ticalcs_calc_type == CALC_TI89)
       && (mask_mode == CLIPPED_SCREEN)) {
     int i, j, k;
 
@@ -170,7 +164,7 @@ int ti89_directorylist(TNode ** tree, uint32_t * memory)
   TRYF(cable->open());
   update_start();
 
-  printl2(0, _("Directory listing...\n"));
+  DISPLAY(_("Directory listing...\n"));
 
   TRYF(ti89_send_REQ(TI89_FDIR << 24, TI89_RDIR, ""));
   TRYF(ti89_recv_ACK(NULL));
@@ -188,13 +182,13 @@ int ti89_directorylist(TNode ** tree, uint32_t * memory)
   TRYF(ti89_send_ACK());
 
   // get list of folders & FLASH apps
-  *tree = t_node_new(NULL);
-  vars = t_node_new(NULL);
-  apps = t_node_new(NULL);
-  t_node_append(*tree, vars);
-  t_node_append(*tree, apps);
+  *tree = g_node_new(NULL);
+  vars = g_node_new(NULL);
+  apps = g_node_new(NULL);
+  g_node_append(*tree, vars);
+  g_node_append(*tree, apps);
 
-  for (j = 4; j < (int)block_size;) {
+  for (j = 4; j < block_size;) {
     TiVarEntry *fe = calloc(1, sizeof(TiVarEntry));
     TNode *node;
 
@@ -207,25 +201,25 @@ int ti89_directorylist(TNode ** tree, uint32_t * memory)
     strcpy(fe->folder, "");
 
     tifiles_translate_varname(fe->name, fe->trans, fe->type);
-    node = t_node_new(fe);
+    node = g_node_new(fe);
 
-    printl2(0, _("Name: %8s | "), fe->name);
-    printl2(0, _("Type: %8s | "), tifiles_vartype2string(fe->type));
-    printl2(0, _("Attr: %i  | "), fe->attr);
-    printl2(0, _("Size: %08X\n"), fe->size);
+    DISPLAY(_("Name: %8s | "), fe->name);
+    DISPLAY(_("Type: %8s | "), tifiles_vartype2string(fe->type));
+    DISPLAY(_("Attr: %i  | "), fe->attr);
+    DISPLAY(_("Size: %08X\n"), fe->size);
 
     if (fe->type == TI89_DIR)
-      t_node_append(vars, node);
+      g_node_append(vars, node);
     else if (fe->type == TI89_APPL)
       continue;			// AMS<2.08 returns FLASH apps
   }
 
   // get list of variables into each folder
-  for (i = 0; i < (int)t_node_n_children(vars); i++) {
-    TNode *folder = t_node_nth_child(vars, i);
+  for (i = 0; i < g_node_n_children(vars); i++) {
+    TNode *folder = g_node_nth_child(vars, i);
     char *folder_name = ((TiVarEntry *) (folder->data))->name;
 
-    printl2(0, _("Directory listing in %8s...\n"), folder_name);
+    DISPLAY(_("Directory listing in %8s...\n"), folder_name);
 
     TRYF(ti89_send_REQ(TI89_LDIR << 24, TI89_RDIR, folder_name));
     TRYF(ti89_recv_ACK(NULL));
@@ -242,7 +236,7 @@ int ti89_directorylist(TNode ** tree, uint32_t * memory)
     TRYF(ti89_recv_EOT());
     TRYF(ti89_send_ACK());
 
-    for (j = 4 + 14 + extra; j < (int)block_size;) {
+    for (j = 4 + 14 + extra; j < block_size;) {
       TiVarEntry *ve = calloc(1, sizeof(TiVarEntry));
       TNode *node;
 
@@ -255,12 +249,12 @@ int ti89_directorylist(TNode ** tree, uint32_t * memory)
       strcpy(ve->folder, folder_name);
 
       tifiles_translate_varname(ve->name, ve->trans, ve->type);
-      node = t_node_new(ve);
+      node = g_node_new(ve);
 
-      printl2(0, _("Name: %8s | "), ve->trans);
-      printl2(0, _("Type: %8s | "), tifiles_vartype2string(ve->type));
-      printl2(0, _("Attr: %i  | "), ve->attr);
-      printl2(0, _("Size: %08X\n"), ve->size);
+      DISPLAY(_("Name: %8s | "), ve->trans);
+      DISPLAY(_("Type: %8s | "), tifiles_vartype2string(ve->type));
+      DISPLAY(_("Attr: %i  | "), ve->attr);
+      DISPLAY(_("Size: %08X\n"), ve->size);
 
       sprintf(update->label_text, _("Reading of '%s/%s'"),
 	      ((TiVarEntry *) (folder->data))->trans, ve->trans);
@@ -270,13 +264,13 @@ int ti89_directorylist(TNode ** tree, uint32_t * memory)
 
       if (ve->type == TI89_APPL) {
 	if (!ticalc_check_if_app_exists(*tree, ve->name))
-	  t_node_append(apps, node);
+	  g_node_append(apps, node);
 	else
-	  free(ve);
+	  g_free(ve);
       } else
-	t_node_append(folder, node);
+	g_node_append(folder, node);
     }
-    printl2(0, "\n");
+    DISPLAY("\n");
   }
 
   *memory = ticalc_dirlist_memused(*tree);
@@ -299,7 +293,7 @@ int ti89_recv_backup(const char *filename, int mask_mode)
   int nvars, ivars = 0;
   int b;
 
-  printl2(0, _("Receiving backup...\n"));
+  DISPLAY(_("Receiving backup...\n"));
 
   // Do a directory list and check for something to backup
   TRYF(ti89_directorylist(&tree, &mem));
@@ -308,18 +302,18 @@ int ti89_recv_backup(const char *filename, int mask_mode)
     return ERR_NO_VARS;
 
   // Check whether the last folder is empty
-  vars = t_node_nth_child(tree, 0);
-  b = t_node_n_children(t_node_nth_child(vars,
-					 t_node_n_children(vars) - 1));
+  vars = g_node_nth_child(tree, 0);
+  b = g_node_n_children(g_node_nth_child(vars,
+					 g_node_n_children(vars) - 1));
 
   // Receive all variables, except FLASH apps
-  i_max = t_node_n_children(vars);
+  i_max = g_node_n_children(vars);
   for (i = 0; i < i_max; i++) {
-    TNode *parent = t_node_nth_child(vars, i);
+    GNode *parent = g_node_nth_child(vars, i);
 
-    j_max = t_node_n_children(parent);
+    j_max = g_node_n_children(parent);
     for (j = 0; j < j_max; j++) {
-      TNode *node = t_node_nth_child(parent, j);
+      GNode *node = g_node_nth_child(parent, j);
 
       TiVarEntry *ve = (TiVarEntry *) (node->data);
 
@@ -353,7 +347,7 @@ int ti89_send_var(const char *filename, int mask_mode, char **actions);
 
 int ti89_send_backup(const char *filename, int mask_mode)
 {
-  printl2(0, _("Sending backup...\n"));
+  DISPLAY(_("Sending backup...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -387,9 +381,9 @@ int ti89_recv_var(char *filename, int mask_mode, TiVarEntry * entry)
   char *fn;
   static int nvar = 0;
   uint32_t unused;
-  uint8_t varname[20], utf8[35];
+  uint8_t varname[18], utf8[35];
 
-  printl2(0, _("Receiving variable(s)...\n"));
+  DISPLAY(_("Receiving variable(s)...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -409,15 +403,15 @@ int ti89_recv_var(char *filename, int mask_mode, TiVarEntry * entry)
   ve = &(content->entries[nvar]);
   memcpy(ve, entry, sizeof(TiVarEntry));
 
-  strcpy((char*)varname, entry->folder);
-  strcat((char*)varname, "\\");
-  strcat((char*)varname, entry->name);
+  strcpy(varname, entry->folder);
+  strcat(varname, "\\");
+  strcat(varname, entry->name);
 
-  tifiles_translate_varname((char*)varname, (char*)utf8, entry->type);
+  tifiles_translate_varname(varname, utf8, entry->type);
   sprintf(update->label_text, _("Receiving '%s'"), utf8);
   update_label();
 
-  TRYF(ti89_send_REQ(0, entry->type, (char*)varname));
+  TRYF(ti89_send_REQ(0, entry->type, varname));
   TRYF(ti89_recv_ACK(&status));
   if (status != 0)
     return ERR_MISSING_VAR;
@@ -466,7 +460,7 @@ int ti89_send_var(const char *filename, int mask_mode, char **actions)
   int i;
   uint16_t status;
 
-  printl2(0, _("Sending variable(s)...\n"));
+  DISPLAY(_("Sending variable(s)...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -484,22 +478,22 @@ int ti89_send_var(const char *filename, int mask_mode, char **actions)
     uint8_t full_name[18], varname[18], utf8[35];
 
     if (actions == NULL)	// backup or old behaviour
-      strcpy((char*)varname, entry->name);
+      strcpy(varname, entry->name);
     else if (actions[i][0] == ACT_SKIP) {
-      printl2(0, _(" '%s' has been skipped !\n"), entry->name);
+      DISPLAY(_(" '%s' has been skipped !\n"), entry->name);
       continue;
     } else if (actions[i][0] == ACT_OVER)
-      strcpy((char*)varname, actions[i] + 1);
+      strcpy(varname, actions[i] + 1);
 
     if ((mask_mode & MODE_LOCAL_PATH) && !(mask_mode & MODE_BACKUP)) {	// local & not backup
-      strcpy((char*)full_name, (char*)varname);
+      strcpy(full_name, varname);
     } else {			// full or backup
-      strcpy((char*)full_name, entry->folder);
-      strcat((char*)full_name, "\\");
-      strcat((char*)full_name, (char*)varname);
+      strcpy(full_name, entry->folder);
+      strcat(full_name, "\\");
+      strcat(full_name, varname);
     }
 
-    tifiles_translate_varname((char*)full_name, (char*)utf8, entry->type);
+    tifiles_translate_varname(full_name, utf8, entry->type);
     sprintf(update->label_text, _("Sending '%s'"), utf8);
     update_label();
 
@@ -515,9 +509,9 @@ int ti89_send_var(const char *filename, int mask_mode, char **actions)
 	vartype = 0x27;
 	break;
       }
-      TRYF(ti89_send_RTS(entry->size, vartype, (char*)full_name));
+      TRYF(ti89_send_RTS(entry->size, vartype, full_name));
     } else {
-      TRYF(ti89_send_VAR(entry->size, vartype, (char*)full_name));
+      TRYF(ti89_send_VAR(entry->size, vartype, full_name));
     }
 
     TRYF(ti89_recv_ACK(NULL));
@@ -534,9 +528,7 @@ int ti89_send_var(const char *filename, int mask_mode, char **actions)
 
     if (mask_mode & MODE_BACKUP) {
       (update->main_percentage) = (float) i / content.num_entries;
-
-    if (update->cancel)
-	        return ERR_ABORT;
+      DISPLAY(_("perc = %1.2f \n"), update->main_percentage);
     }
   }
 
@@ -548,98 +540,6 @@ int ti89_send_var(const char *filename, int mask_mode, char **actions)
   return 0;
 }
 
-// automatically build filename and put it into 'filename'.
-// mask_mode is unused
-// 'entry' contains informations
-int ti89_recv_var_2(char *filename, int mask_mode, TiVarEntry * entry)
-{
-	Ti9xRegular *content;
-	uint32_t unused;
-	uint8_t utf8[35];
-	int nvar, err;
-    char tipath[18];
-    char *tiname;
-
-	printl2(0, _("Receiving variable(s)...\n"));
-
-	// open cable
-	LOCK_TRANSFER();
-	TRYF(cable->open());
-	update_start();
-
-	// create variable content and fills
-    content = ti9x_create_regular_content();
-	content->calc_type = ticalcs_calc_type;
-
-	// receive packets
-	for(nvar = 1;; nvar++)
-	{
-		TiVarEntry *ve;
-
-		content->entries = (TiVarEntry *) tifiles_realloc(content->entries, nvar * sizeof(TiVarEntry));
-		ve = &(content->entries[nvar-1]);
-		strcpy(ve->folder, "main");	
-
-		err = ti89_recv_VAR(&ve->size, &ve->type, tipath);
-		TRYF(ti89_send_ACK());
-
-		if(err == ERR_EOT)	// end of transmission
-			goto exit;
-		else
-			content->num_entries = nvar;
-
-		// from Christian (TI can send varname or fldname/varname)
-        if ((tiname = strchr(tipath, '\\')) != NULL) 
-		{
-			*tiname = '\0';
-            strcpy(ve->folder, tipath);
-            strcpy(ve->name, tiname + 1);
-        }
-        else 
-		{
-            strcpy(ve->folder, "main");
-            strcpy(ve->name, tipath);
-        }
-
-		tifiles_translate_varname(ve->name, (char*)utf8, ve->type);
-		sprintf(update->label_text, _("Receiving '%s'"), utf8);
-		update_label();
-
-		TRYF(ti89_send_CTS());
-		TRYF(ti89_recv_ACK(NULL));
-
-		ve->data = tifiles_calloc(ve->size + 4, 1);
-		TRYF(ti89_recv_XDP(&unused, ve->data));
-		memmove(ve->data, ve->data + 4, ve->size);
-		TRYF(ti89_send_ACK());
-	}
-
-exit:
-	// close cable
-	TRYF(cable->close());
-	UNLOCK_TRANSFER();
-    
-	// write file content
-	nvar--;
-	if(nvar > 1)
-	{
-		strcpy(content->comment, "Group file received by TiLP");
-		strcat(filename, "group.92g");
-		ti9x_write_regular_file(filename, content, NULL);
-	}
-	else
-	{
-		strcpy(content->comment, "Single file received by TiLP");
-		strcat(filename, content->entries[0].name);
-		strcat(filename, ".");
-		strcat(filename, tifiles_vartype2file(content->entries[0].type));
-		ti9x_write_regular_file(filename, content, NULL);
-	}
-    ti9x_free_regular_content(content);
-
-	return 0;
-}
-
 int ti89_send_flash(const char *filename, int mask_mode)
 {
   Ti9xFlash content = { 0 };
@@ -647,7 +547,7 @@ int ti89_send_flash(const char *filename, int mask_mode)
   int i, nblocks;
   int nheaders = 0;
 
-  printl2(0, _("Sending FLASH app/os...\n"));
+  DISPLAY(_("Sending FLASH app/os...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -666,22 +566,12 @@ int ti89_send_flash(const char *filename, int mask_mode)
   for (i = 0, ptr = &content; i < nheaders - 1; i++)
     ptr = ptr->next;
 
-  printl2(0, _("FLASH app/os name: \"%s\"\n"), ptr->name);
-  printl2(0, _("FLASH app/os size: %i bytes.\n"), ptr->data_length);
+  DISPLAY(_("FLASH app/os name: \"%s\"\n"), ptr->name);
+  DISPLAY(_("FLASH app/os size: %i bytes.\n"), ptr->data_length);
 
-  if (ptr->data_type == TI89_AMS) 
-  {
-	  if(ticalcs_calc_type == CALC_TI89T)
-	  {
-		TRYF(ti89_send_RTS2(ptr->data_length, ptr->data_type, ""));
-	  }
-	  else
-	  {
-		TRYF(ti89_send_RTS(ptr->data_length, ptr->data_type, ""));
-	  }
-  } 
-  else 
-  {
+  if (ptr->data_type == TI89_AMS) {
+    TRYF(ti89_send_RTS(ptr->data_length, ptr->data_type, ""));
+  } else {
     TRYF(ti89_send_RTS(ptr->data_length, ptr->data_type, ptr->name));
   }
 
@@ -704,13 +594,12 @@ int ti89_send_flash(const char *filename, int mask_mode)
     }
 
     update->main_percentage = (float) i / nblocks;
-    if (update->cancel)
-	return ERR_ABORT;
   }
 
-  TRYF(ti89_recv_ACK(NULL));
+  if (ptr->data_type == TI89_AMS)
+    TRYF(ti89_recv_ACK(NULL));
 
-  printl2(0, _("Flash application/os sent completely.\n"));
+  DISPLAY(_("Flash application/os sent completely.\n"));
 
   TRYF(cable->close());
   UNLOCK_TRANSFER();
@@ -723,7 +612,7 @@ int ti89_recv_flash(const char *filename, int mask_mode, TiVarEntry * ve)
   Ti9xFlash *content;
   int i;
 
-  printl2(0, _("Receiving FLASH application...\n"));
+  DISPLAY(_("Receiving FLASH application...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -780,7 +669,7 @@ int ti89_recv_flash(const char *filename, int mask_mode, TiVarEntry * ve)
 }
 
 #define DUMP_ROM89_FILE "dumprom.89z"
-//#define ROMSIZE (2*1024)	// 2MB or 4MB (Titanium)
+#define ROMSIZE (2*1024)	// 2MB
 
 int ti89_dump_rom(const char *filename, int mask_mode)
 {
@@ -792,10 +681,8 @@ int ti89_dump_rom(const char *filename, int mask_mode)
   int pad;
   FILE *f, *file;
   uint16_t checksum, sum;
-  int ROMSIZE = (ticalcs_calc_type == CALC_TI89T) || 
-  				(ticalcs_calc_type == CALC_V200) ? 4*1024 : 2*1024;
 
-  printl2(0, _("ROM dumping...\n"));
+  DISPLAY(_("ROM dumping...\n"));
 
   // Copies ROM dump program into a file
   f = fopen(DUMP_ROM89_FILE, "wb");
@@ -822,13 +709,13 @@ int ti89_dump_rom(const char *filename, int mask_mode)
   TRY(ti89_send_key('i'));
   TRY(ti89_send_key('n'));
   TRY(ti89_send_key('\\'));
-  TRY(ti89_send_key('r'));
-  TRY(ti89_send_key('o'));
-  TRY(ti89_send_key('m'));
   TRY(ti89_send_key('d'));
   TRY(ti89_send_key('u'));
   TRY(ti89_send_key('m'));
   TRY(ti89_send_key('p'));
+  TRY(ti89_send_key('r'));
+  TRY(ti89_send_key('o'));
+  TRY(ti89_send_key('m'));
   TRY(ti89_send_key(KEY89_LP));
   TRY(ti89_send_key(KEY89_RP));
   TRY(ti89_send_key(KEY89_ENTER));
@@ -877,7 +764,7 @@ int ti89_dump_rom(const char *filename, int mask_mode)
       return -1;
 
     elapsed = (long) difftime(time(NULL), start);
-    estimated = (long) (elapsed * (float) (ROMSIZE) / i);
+    estimated = (long) (elapsed * (float) (1024 * 2) / i);
     remaining = (long) difftime(estimated, elapsed);
     sprintf(buffer, "%s", ctime(&remaining));
     sscanf(buffer, "%3s %3s %i %s %i", tmp, tmp, &pad, tmp, &pad);
@@ -900,7 +787,7 @@ int ti89_get_idlist(char *id)
   uint8_t vartype;
   uint8_t varname[9];
 
-  printl2(0, _("Getting ID list...\n"));
+  DISPLAY(_("Getting ID list...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -912,13 +799,13 @@ int ti89_get_idlist(char *id)
   TRYF(ti89_send_REQ(0x0000, TI89_IDLIST, ""));
   TRYF(ti89_recv_ACK(NULL));
 
-  TRYF(ti89_recv_VAR(&varsize, &vartype, (char*)varname));
+  TRYF(ti89_recv_VAR(&varsize, &vartype, varname));
   TRYF(ti89_send_ACK());
 
   TRYF(ti89_send_CTS());
   TRYF(ti89_recv_ACK(NULL));
 
-  TRYF(ti89_recv_XDP(&varsize, (uint8_t*)id));
+  TRYF(ti89_recv_XDP(&varsize, id));
   id[varsize] = '\0';
   TRYF(ti89_send_ACK());
 
@@ -938,7 +825,7 @@ int ti89_get_clock(TicalcClock * clock, int mode)
   uint8_t varname[9];
   uint8_t buffer[32];
 
-  printl2(0, _("Getting clock...\n"));
+  DISPLAY(_("Getting clock...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -950,7 +837,7 @@ int ti89_get_clock(TicalcClock * clock, int mode)
   TRYF(ti89_send_REQ(0x0000, TI89_CLK, "Clock"));
   TRYF(ti89_recv_ACK(NULL));
 
-  TRYF(ti89_recv_VAR(&varsize, &vartype, (char*)varname));
+  TRYF(ti89_recv_VAR(&varsize, &vartype, varname));
   TRYF(ti89_send_ACK());
 
   TRYF(ti89_send_CTS());
@@ -993,7 +880,7 @@ int ti89_set_clock(const TicalcClock * clock, int mode)
   buffer[14] = clock->time_format;
   buffer[15] = 0xff;
 
-  printl2(0, _("Setting clock...\n"));
+  DISPLAY(_("Setting clock...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
