@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: ti92.c 1926 2006-02-25 13:46:26Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,8 +25,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include "gettext.h"
-
+#include "intl2.h"
 #include "headers.h"
 #include "externs.h"
 #include "update.h"
@@ -40,7 +36,6 @@
 #include "keys92p.h"
 #include "pause.h"
 #include "dirlist.h"
-#include "printl.h"
 
 // Screen coordinates of the TI92
 #define TI92_ROWS  128
@@ -57,6 +52,25 @@ int ti92_supported_operations(void)
        OPS_SEND_VARS | OPS_RECV_VARS | OPS_ROMVERSION | OPS_ROMDUMP);
 }
 
+int ti92_isready(void)
+{
+  uint16_t status;
+
+  DISPLAY(_("Is calculator ready ?\n"));
+
+  LOCK_TRANSFER();
+  TRYF(cable->open());
+  update_start();
+
+  TRYF(ti92_send_RDY());
+  TRYF(ti92_recv_ACK(&status));
+
+  TRYF(cable->close());
+  UNLOCK_TRANSFER();
+
+  return (status & 0x01) ? ERR_NOT_READY : 0;
+}
+
 int ti92_send_key(uint16_t key)
 {
   LOCK_TRANSFER();
@@ -71,32 +85,13 @@ int ti92_send_key(uint16_t key)
   return 0;
 }
 
-int ti92_isready(void)
-{
-  uint16_t status;
-
-  printl2(0, _("Is calculator ready ?\n"));
-
-  LOCK_TRANSFER();
-  TRYF(cable->open());
-  update_start();
-
-  TRYF(ti92_send_RDY());
-  TRYF(ti92_recv_ACK(&status));
-
-  TRYF(cable->close());
-  UNLOCK_TRANSFER();
-
-  return (status & 0x0100) ? ERR_NOT_READY : 0;
-}
-
 int ti92_screendump(uint8_t ** bitmap, int mask_mode,
 		    TicalcScreenCoord * sc)
 {
   uint32_t max_cnt;
   int err;
 
-  printl2(0, _("Receiving screendump...\n"));
+  DISPLAY(_("Receiving screendump...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -112,7 +107,7 @@ int ti92_screendump(uint8_t ** bitmap, int mask_mode,
   (*bitmap) =
       (uint8_t *) malloc(TI92_COLS * TI92_ROWS * sizeof(uint8_t) / 8);
   if ((*bitmap) == NULL) {
-    printl2(2, "Unable to allocate memory.\n");
+    fprintf(stderr, "Unable to allocate memory.\n");
     exit(0);
   }
 
@@ -124,7 +119,7 @@ int ti92_screendump(uint8_t ** bitmap, int mask_mode,
   TRYF(err)};
   TRYF(ti92_send_ACK());
 
-  printl2(0, _("Done.\n"));
+  DISPLAY(_("Done.\n"));
 
   TRYF(cable->close());
   UNLOCK_TRANSFER();
@@ -146,18 +141,18 @@ int ti92_directorylist(TNode ** tree, uint32_t * memory)
   TRYF(cable->open());
   update_start();
 
-  printl2(0, _("Directory listing...\n"));
+  DISPLAY(_("Directory listing...\n"));
 
   TRYF(ti92_send_REQ(0, TI92_RDIR, ""));
   TRYF(ti92_recv_ACK(NULL));
 
   TRYF(ti92_recv_VAR(&info.size, &info.type, info.name));
 
-  *tree = t_node_new(NULL);
-  vars = t_node_new(NULL);
-  apps = t_node_new(NULL);
-  t_node_append(*tree, vars);
-  t_node_append(*tree, apps);
+  *tree = g_node_new(NULL);
+  vars = g_node_new(NULL);
+  apps = g_node_new(NULL);
+  g_node_append(*tree, vars);
+  g_node_append(*tree, apps);
 
   for (;;) {
     TiVarEntry *ve = calloc(1, sizeof(TiVarEntry));
@@ -177,20 +172,20 @@ int ti92_directorylist(TNode ** tree, uint32_t * memory)
     strcpy(ve->folder, "");
 
     tifiles_translate_varname(ve->name, ve->trans, ve->type);
-    node = t_node_new(ve);
+    node = g_node_new(ve);
 
     if (ve->type == TI92_DIR) {
       strcpy(folder_name, ve->name);
-      folder = t_node_append(vars, node);
+      folder = g_node_append(vars, node);
     } else {
       strcpy(ve->folder, folder_name);
-      t_node_append(folder, node);
+      g_node_append(folder, node);
     }
 
-    printl2(0, _("Name: %8s | "), ve->name);
-    printl2(0, _("Type: %8s | "), tifiles_vartype2string(ve->type));
-    printl2(0, _("Attr: %i  | "), ve->attr);
-    printl2(0, _("Size: %08X\n"), ve->size);
+    DISPLAY(_("Name: %8s | "), ve->name);
+    DISPLAY(_("Type: %8s | "), tifiles_vartype2string(ve->type));
+    DISPLAY(_("Attr: %i  | "), ve->attr);
+    DISPLAY(_("Size: %08X\n"), ve->size);
 
     TRYF(ti92_send_ACK());
     err = ti92_recv_CONT();
@@ -221,10 +216,9 @@ int ti92_recv_backup(const char *filename, int mask_mode)
   uint32_t block_size;
   int block, err;
   uint32_t unused;
-  uint16_t unused2;
   uint8_t *ptr;
 
-  printl2(0, _("Receiving backup...\n"));
+  DISPLAY(_("Receiving backup...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -236,7 +230,8 @@ int ti92_recv_backup(const char *filename, int mask_mode)
 
   // silent request
   TRYF(ti92_send_REQ(0, TI92_BKUP, "main\\backup"));
-  TRYF(ti92_recv_ACK(&unused2));
+  printf("filename = <%s>\n", filename);
+  TRYF(ti92_recv_ACK((uint16_t *) & unused));
 
   content.data_part = (uint8_t *) tifiles_calloc(128 * 1024, 1);
   content.type = TI92_BKUP;
@@ -278,7 +273,7 @@ int ti92_send_backup(const char *filename, int mask_mode)
   Ti9xBackup content = { 0 };
   int i, nblocks;
 
-  printl2(0, _("Sending backup...\n"));
+  DISPLAY(_("Sending backup...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -331,7 +326,7 @@ int ti92_recv_var(char *filename, int mask_mode, TiVarEntry * entry)
   uint32_t unused;
   uint8_t varname[18], utf8[35];
 
-  printl2(0, _("Receiving variable(s)...\n"));
+  DISPLAY(_("Receiving variable(s)...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -351,15 +346,15 @@ int ti92_recv_var(char *filename, int mask_mode, TiVarEntry * entry)
   ve = &(content->entries[nvar]);
   memcpy(ve, entry, sizeof(TiVarEntry));
 
-  strcpy((char*)varname, entry->folder);
-  strcat((char*)varname, "\\");
-  strcat((char*)varname, entry->name);
+  strcpy(varname, entry->folder);
+  strcat(varname, "\\");
+  strcat(varname, entry->name);
 
-  tifiles_translate_varname((char*)varname, (char*)utf8, entry->type);
+  tifiles_translate_varname(varname, utf8, entry->type);
   sprintf(update->label_text, _("Receiving '%s'"), utf8);
   update_label();
 
-  TRYF(ti92_send_REQ(0, entry->type, (char*)varname));
+  TRYF(ti92_send_REQ(0, entry->type, varname));
   TRYF(ti92_recv_ACK(&status));
   if (status != 0)
     return ERR_MISSING_VAR;
@@ -408,7 +403,7 @@ int ti92_send_var(const char *filename, int mask_mode, char **actions)
   int i;
   uint16_t status;
 
-  printl2(0, _("Sending variable(s)...\n"));
+  DISPLAY(_("Sending variable(s)...\n"));
 
   LOCK_TRANSFER();
   TRYF(cable->open());
@@ -425,26 +420,26 @@ int ti92_send_var(const char *filename, int mask_mode, char **actions)
     uint8_t full_name[18], varname[18], utf8[35];
 
     if (actions == NULL)	// backup or old behaviour
-      strcpy((char*)varname, entry->name);
+      strcpy(varname, entry->name);
     else if (actions[i][0] == ACT_SKIP) {
-      printl2(0, _(" '%s' has been skipped !\n"), entry->name);
+      DISPLAY(_(" '%s' has been skipped !\n"), entry->name);
       continue;
     } else if (actions[i][0] == ACT_OVER)
-      strcpy((char*)varname, actions[i] + 1);
+      strcpy(varname, actions[i] + 1);
 
     if (mask_mode & MODE_LOCAL_PATH)
-      strcpy((char*)full_name, (char*)varname);
+      strcpy(full_name, varname);
     else {
-      strcpy((char*)full_name, entry->folder);
-      strcat((char*)full_name, "\\");
-      strcat((char*)full_name, (char*)varname);
+      strcpy(full_name, entry->folder);
+      strcat(full_name, "\\");
+      strcat(full_name, varname);
     }
 
-    tifiles_translate_varname((char*)full_name, (char*)utf8, entry->type);
+    tifiles_translate_varname(full_name, utf8, entry->type);
     sprintf(update->label_text, _("Sending '%s'"), utf8);
     update_label();
 
-    TRYF(ti92_send_VAR(entry->size, entry->type, (char*)varname));
+    TRYF(ti92_send_VAR(entry->size, entry->type, varname));
     TRYF(ti92_recv_ACK(NULL));
 
     TRYF(ti92_recv_CTS());
@@ -457,7 +452,7 @@ int ti92_send_var(const char *filename, int mask_mode, char **actions)
     TRYF(ti92_send_EOT());
     TRYF(ti92_recv_ACK(NULL));
 
-    printl2(0, "\n");
+    DISPLAY("\n");
   }
 
   ti9x_free_regular_content(&content);
@@ -468,95 +463,6 @@ int ti92_send_var(const char *filename, int mask_mode, char **actions)
   return 0;
 }
 
-int ti92_recv_var_2(char *filename, int mask_mode, TiVarEntry *entry)
-{
-	Ti9xRegular *content;
-	uint32_t unused;
-	uint8_t utf8[35];
-	int nvar, err;
-    char tipath[18];
-    char *tiname;
-
-	printl2(0, _("Receiving variable(s)...\n"));
-
-	// open cable
-	LOCK_TRANSFER();
-	TRYF(cable->open());
-	update_start();
-
-	// create variable content and fills
-    content = ti9x_create_regular_content();
-	content->calc_type = ticalcs_calc_type;
-
-	// receive packets
-	for(nvar = 1;; nvar++)
-	{
-		TiVarEntry *ve;
-
-		content->entries = (TiVarEntry *) tifiles_realloc(content->entries, nvar * sizeof(TiVarEntry));
-		ve = &(content->entries[nvar-1]);
-		strcpy(ve->folder, "main");	
-
-		err = ti92_recv_VAR(&ve->size, &ve->type, tipath);
-		TRYF(ti92_send_ACK());
-
-		if(err == ERR_EOT)	// end of transmission
-			goto exit;
-		else
-			content->num_entries = nvar;
-
-		// from Christian (TI can send varname or fldname/varname)
-        if ((tiname = strchr(tipath, '\\')) != NULL) 
-		{
-			*tiname = '\0';
-            strcpy(ve->folder, tipath);
-            strcpy(ve->name, tiname + 1);
-        }
-        else 
-		{
-            strcpy(ve->folder, "main");
-            strcpy(ve->name, tipath);
-        }
-
-		tifiles_translate_varname((char*)ve->name, (char*)utf8, ve->type);
-		sprintf(update->label_text, _("Receiving '%s'"), utf8);
-		update_label();
-
-		TRYF(ti92_send_CTS());
-		TRYF(ti92_recv_ACK(NULL));
-
-		ve->data = tifiles_calloc(ve->size + 4, 1);
-		TRYF(ti92_recv_XDP(&unused, ve->data));
-		memmove(ve->data, ve->data + 4, ve->size);
-		TRYF(ti92_send_ACK());
-	}
-
-exit:
-	// close cable
-	TRYF(cable->close());
-	UNLOCK_TRANSFER();
-    
-	// write file content
-	nvar--;
-	if(nvar > 1)
-	{
-		strcpy(content->comment, "Group file received by TiLP");
-		strcat(filename, "group.92g");
-		ti9x_write_regular_file(filename, content, NULL);
-	}
-	else
-	{
-		strcpy(content->comment, "Single file received by TiLP");
-		strcat(filename, content->entries[0].name);
-		strcat(filename, ".");
-		strcat(filename, tifiles_vartype2file(content->entries[0].type));
-		ti9x_write_regular_file(filename, content, NULL);
-	}
-    ti9x_free_regular_content(content);
-
-	return 0;
-}
-
 int ti92_send_flash(const char *filename, int mask_mode)
 {
   return ERR_VOID_FUNCTION;
@@ -581,7 +487,7 @@ int ti92_dump_rom(const char *filename, int mask_mode)
   FILE *f, *file;
   uint16_t checksum, sum;
 
-  printl2(0, _("ROM dumping...\n"));
+  DISPLAY(_("ROM dumping...\n"));
 
   // Copies ROM dump program into a file
   f = fopen(DUMP_ROM92_FILE, "wb");
