@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: ticalcs.h 826 2004-12-27 21:52:48Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,17 +19,9 @@
 #ifndef __TICALCS__
 #define __TICALCS__
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 #include "calc_def.h"
 #include "calc_int.h"
 #include "calc_err.h"
 #include "calc_ver.h"
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif
