@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: tikeys.c 1397 2005-07-20 10:55:03Z roms $ */
-
-/*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libticalcs - calculator library, a part of the TiLP project
+ *  Copyright (C) 1999-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,22 +30,22 @@ extern const TicalcKey TI89_KEYS[];
 extern const TicalcKey TI92P_KEYS[];
 
 
-TIEXPORT TicalcKey TICALL ticalc_73_keys(unsigned char ascii_code)
+TIEXPORT const TicalcKey TICALL ticalc_73_keys(unsigned char ascii_code)
 {
   return TI73_KEYS[ascii_code];
 }
 
-TIEXPORT TicalcKey TICALL ticalc_83p_keys(unsigned char ascii_code)
+TIEXPORT const TicalcKey TICALL ticalc_83p_keys(unsigned char ascii_code)
 {
   return TI83P_KEYS[ascii_code];
 }
 
-TIEXPORT TicalcKey TICALL ticalc_89_keys(unsigned char ascii_code)
+TIEXPORT const TicalcKey TICALL ticalc_89_keys(unsigned char ascii_code)
 {
   return TI89_KEYS[ascii_code];
 }
 
-TIEXPORT TicalcKey TICALL ticalc_92p_keys(unsigned char ascii_code)
+TIEXPORT const TicalcKey TICALL ticalc_92p_keys(unsigned char ascii_code)
 {
   return TI92P_KEYS[ascii_code];
 }
